### This file is used to calculate poverty and inequality impact of policy scenarios simulated in GAMS.

# Copyright 2011 Ulrich Kleinwechter.

# This file is part of Guimod 1.01.

# Guimod is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

# Guimod is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along with Guimod.  If not, see <http://www.gnu.org/licenses/>.


# At the beginning: Set working directory to the path where the GAMS program is located
setwd("C:/Users/Uli/Desktop/guimod1.01")

rm(list=ls())

library(gdata)
library(reldist)
library(lawstat)

#####
## 1. Load data and functions
#####
# Make sure that all data files as well as the FGT functions are in the directory with the GAMS model code which also should be the working directory

## Load data with results
# If on Windows, specify path to perl.exe
daten <- read.xls("guimod1.01_incchange_sims_lib.xls",sheet=3,perl="C:/strawberry/perl/bin/perl.exe")
daten2 <- read.xls("guimod1.01_incchange_sims_lib.xls",sheet=2,perl="C:/strawberry/perl/bin/perl.exe")

## Load household data
hholddat <- read.csv2("povanalydat.csv")

## Load functions for FGT poverty indizes
load("P0func.r")
load("P1func.r")
load("P2func.r")

#####
### 2. Prepare data for calculations
#####

# Poverty lines:
zlowb  <- hholddat$povlow06[1]
zhighb <- hholddat$povhigh06[1]
zlow  <- hholddat$povlow06[1]*daten2$sim01[1]
zhigh <- hholddat$povhigh06[1]*daten2$sim01[1]

# Attach multiplication factors (simulated %change in income) to household data
# For simulation 1:
facsim01 <- with(hholddat,ifelse(RHG==11,daten$sim01[1],
                          ifelse(RHG==12,daten$sim01[2],
                          ifelse(RHG==13,daten$sim01[3],
                          ifelse(RHG==21,daten$sim01[4],
                          ifelse(RHG==22,daten$sim01[5],
                          daten$sim01[6]
                          ))))))
multfacsim01 <- 1+facsim01/100
# For simulation 2:
facsim02 <- with(hholddat,ifelse(RHG==11,daten$sim02[1],
                          ifelse(RHG==12,daten$sim02[2],
                          ifelse(RHG==13,daten$sim02[3],
                          ifelse(RHG==21,daten$sim02[4],
                          ifelse(RHG==22,daten$sim02[5],
                          daten$sim02[6]
                          ))))))
multfacsim02 <- 1+facsim02/100
# For simulation 3:
facsim03 <- with(hholddat,ifelse(RHG==11,daten$sim03[1],
                          ifelse(RHG==12,daten$sim03[2],
                          ifelse(RHG==13,daten$sim03[3],
                          ifelse(RHG==21,daten$sim03[4],
                          ifelse(RHG==22,daten$sim03[5],
                          daten$sim03[6]
                          ))))))
multfacsim03 <- 1+facsim03/100
# For simulation 4:
facsim04 <- with(hholddat,ifelse(RHG==11,daten$sim04[1],
                          ifelse(RHG==12,daten$sim04[2],
                          ifelse(RHG==13,daten$sim04[3],
                          ifelse(RHG==21,daten$sim04[4],
                          ifelse(RHG==22,daten$sim04[5],
                          daten$sim04[6]
                          ))))))
multfacsim04 <- 1+facsim04/100

#####
### 3. Compute poverty and inequality measures
#####

attach(hholddat)

## Base 
p0lobase <- P0func(incmeas,hhsize,zlowb)
p0hibase <- P0func(incmeas,hhsize,zhighb)
p1lobase <- P1func(incmeas,hhsize,zlowb)
p1hibase <- P1func(incmeas,hhsize,zhighb)
p2lobase <- P2func(incmeas,hhsize,zlowb)
p2hibase <- P2func(incmeas,hhsize,zhighb)
ginibase <- gini(incmeas/hhsize,weights=hhsize)*100

## Simulation 1
incmeas01 <- incmeas*multfacsim01 # Maps income changes to incmeas
p0losim01  <- P0func(incmeas01,hhsize,zlow)
p0hisim01  <- P0func(incmeas01,hhsize,zhigh)
p1losim01  <- P1func(incmeas01,hhsize,zlow)
p1hisim01  <- P1func(incmeas01,hhsize,zhigh)
p2losim01  <- P2func(incmeas01,hhsize,zlow)
p2hisim01  <- P2func(incmeas01,hhsize,zhigh)
ginisim01  <- gini(incmeas01/hhsize,weights=hhsize)*100

## Simulation 2
incmeas02 <- incmeas*multfacsim02 # Maps income changes to incmeas
p0losim02  <- P0func(incmeas02,hhsize,zlow)
p0hisim02  <- P0func(incmeas02,hhsize,zhigh)
p1losim02  <- P1func(incmeas02,hhsize,zlow)
p1hisim02  <- P1func(incmeas02,hhsize,zhigh)
p2losim02  <- P2func(incmeas02,hhsize,zlow)
p2hisim02  <- P2func(incmeas02,hhsize,zhigh)
ginisim02  <- gini(incmeas02/hhsize,weights=hhsize)*100

## Simulation 3
incmeas03 <- incmeas*multfacsim03 # Maps income changes to incmeas
p0losim03  <- P0func(incmeas03,hhsize,zlow)
p0hisim03  <- P0func(incmeas03,hhsize,zhigh)
p1losim03  <- P1func(incmeas03,hhsize,zlow)
p1hisim03  <- P1func(incmeas03,hhsize,zhigh)
p2losim03  <- P2func(incmeas03,hhsize,zlow)
p2hisim03  <- P2func(incmeas03,hhsize,zhigh)
ginisim03  <- gini(incmeas03/hhsize,weights=hhsize)*100

## Simulation 4
incmeas04 <- incmeas*multfacsim04 # Maps income changes to incmeas
p0losim04  <- P0func(incmeas04,hhsize,zlow)
p0hisim04  <- P0func(incmeas04,hhsize,zhigh)
p1losim04  <- P1func(incmeas04,hhsize,zlow)
p1hisim04  <- P1func(incmeas04,hhsize,zhigh)
p2losim04  <- P2func(incmeas04,hhsize,zlow)
p2hisim04  <- P2func(incmeas04,hhsize,zhigh)
ginisim04  <- gini(incmeas04/hhsize,weights=hhsize)*100

detach(hholddat)

#####
### 4. Collect results
#####

baseres   <- round(t(cbind(p0lobase,p0hibase,p1lobase,p1hibase,p2lobase,p2hibase,ginibase)),6)
sim01res  <- round(t(cbind(p0losim01,p0hisim01,p1losim01,p1hisim01,p2losim01,p2hisim01,ginisim01)),6)
sim02res  <- round(t(cbind(p0losim02,p0hisim02,p1losim02,p1hisim02,p2losim02,p2hisim02,ginisim02)),6)
sim03res  <- round(t(cbind(p0losim03,p0hisim03,p1losim03,p1hisim03,p2losim03,p2hisim03,ginisim03)),6)
sim04res  <- round(t(cbind(p0losim04,p0hisim04,p1losim04,p1hisim04,p2losim04,p2hisim04,ginisim04)),6)
povimpact <- data.frame(cbind(baseres,sim01res,sim02res,sim03res,sim04res))
names(povimpact)[1] <- "base"
names(povimpact)[2] <- "sim01"
names(povimpact)[3] <- "sim02"
names(povimpact)[4] <- "sim03"
names(povimpact)[5] <- "sim04"
row.names(povimpact)[1] <- "p0lo"
row.names(povimpact)[2] <- "p0hi"
row.names(povimpact)[3] <- "p1lo"
row.names(povimpact)[4] <- "p1hi"
row.names(povimpact)[5] <- "p2lo"
row.names(povimpact)[6] <- "p2hi"
row.names(povimpact)[7] <- "gini"
print(povimpact)
write.csv2(povimpact,file="guimod1.01_povimpacts_sims_lib.csv")
