# Date: 25 March, 2011
# Author: Ulrich Kleinwechter
# Agricultural and Food Policy Group, University of Hohenheim

####### INTRODUCTION #######

# This file is part of the dissertation Kleinwechter U. (2011), Village level impacts of trade reform in China. University of Hohenheim.
# This file has been used to compile and balance the SAM for Changtian village (see Chapter 5 in the dissertation). It is provided mainly for reasons of documentation, in particular on the balancing process. In case it proofs useful for any other purpose, however, feel free to use it.

# Copyright 2011 Ulrich Kleinwechter.

# This script is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version. This script is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with Guimod.  If not, see <http://www.gnu.org/licenses/>.
###


######## BEGINNING OF PROGRAM #######

### Decision: Due to lots of zero values in the use of factors by the different activities it does not make much sense to dissagregate the off-farm activities as detailed as it would be in principle possible from the survey. Hence: Aggregate the previously five migration activities to only one, aggregate the previously five local off-farm activities to only two, formal (awage) and informal (aoffinf) 

rm(list=ls())

library(gdata)

###
## A. PREPARATION
###

## 1. SET UP THE FRAME OF THE SAM TO BE FILLED WITH DATA

# Import row and column names of the SAM
SAMnames <- read.xls("/home/uli/Dropbox/Diss/Model/VillSAM/SAM_hhdisagg_actagg_agragg.xls", sheet=7)

# Generate matrix frame 
SAMmatrix <- matrix(data=rep(0,length(attributes(SAMnames)$row.names^2)),nrow=length(attributes(SAMnames)$row.names),ncol=length(attributes(SAMnames)$row.names),dimnames=list(SAMnames$NAMES,SAMnames$NAMES))

## 2. LOAD OTHER DATA NEEDED

 incomes1  <- read.csv2("csvs/incomes1_IFPRI.csv")    # Household supply for sale and own consumption
 incomes2  <- read.csv2("csvs/incomes2_IFPRI.csv")    # Income from local agr. employment
 nonaginc  <- read.csv2("csvs/nonfarminc.labtype.csv")# Nonagricultural employment by labor type
 landconv  <- read.csv2("csvs/landconv.csv")          # Income from land rentals
 landpr    <- read.csv2("csvs/landlabprices.csv")     # Shadow prices for land
 aginputs1 <- read.csv2("csvs/aginputs_agg.csv")      # Expenditures on agricultural inputs 1
 aginputs2 <- read.csv2("csvs/agr_inputs.csv")        # Expenditures on agricultural inputs 2
 expense1  <- read.csv2("csvs/expenditures_IFPRI.csv")# Expenditures on consumption goods and services
 expense2  <- read.csv2("csvs/exp_selfcons.csv")      # Own consumption of agricultural products
 shock     <- read.csv2("csvs/shock.csv")             # Expenditure on shocks
 time      <- read.csv2("csvs/nonaglabval.csv")       # Value of leisure consumption 
 RHGs      <- read.csv2("csvs/RHGs.csv")              # Representative household groups
 
 SAMdat   <- incomes1
 SAMdat   <- merge(incomes1,incomes2,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,nonaginc,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,landconv,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,aginputs1,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,aginputs2,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,expense1,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,expense2,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,shock,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,time,by="hh",all.x=TRUE)
 SAMdat   <- merge(SAMdat,landpr,by="hh",all.x=TRUE)
 names(RHGs)[2] <-"hh"
 SAMdat   <- merge(SAMdat,RHGs,by="hh",all.x=TRUE)
 SAMdat[is.na(SAMdat)] <- 0

# Select data for village 1

 SAMdat1  <- SAMdat[which(SAMdat$vid.x==1),]

#####
### B. FILL SAM WITH PROFITS
#####

 attach(SAMdat1)

### SAM balancing: Principal problems at the beginning are
#                   - excess receipts of agricultural activities
#                   - income of households is too low
#                   - imbalances in the trgift account

# Start with proportionally scaling up input use by agricultural activities
## SAM balancing: Scale up payments by the agricultural activities of each household proportionally to balance the agricultural activity accounts

  aginpscal  <- 1.0 * 1.0
  aginpscal11 <- 1.0 * 1.57696748547908 * 1.6413
  aginpscal12 <- 1.0 * 1.06814369782141 * 1.7211
  aginpscal13 <- 1.0 * 1.17345540664386 * 1.6199
  aginpscal21 <- 1.0 * 1.07541296239168 * 1.7669
  aginpscal22 <- 1.0 * 0.985690652938612 * 2.31221	
  aginpscal23 <- 1.0 * 1.1052480046066 * 1.9821

### SAM balancing: The scaling of input use by agricultural activites leads to imbalances in the payments to the factor accounts from land and labor as well as in the payments from these factors to the households. 
# Adjust these entries to match the new expenses on inputs.
# Scale payments by the farm labor accounts proportionally

 flabmadfscal   <- 1.0 * 1.14297239544721
 flabmecfscal   <- 1.0 * 1.13189143341815 
 flabfemadfscal <- 1.0 * 1.1487188365651	
 flabfemecfscal <- 1.0 * 1.129023532594
# Scale payments by land accounts proportionally
 flndirrscal    <- 1.0 * 1.1593488836223	
 flndnirrscal   <- 1.0 * 1.15152140061445

### Via clabagvil, the adjustment of agricultural input use has changed the amount of village labor employed. This requires to change receipts and payments ofand from aoffinc*. The SAM is programmed in a way that payments from clabagvil to aoffinc autmatically adjust to changes in use of clabagvil in agriculture. Payments from aoffinc to households, however, remain as before. This means that changes in agr. input use does not affect income of households from aoffinc but rather the composition of income from aoffinc with respect to income sources. In the way income from labagvil increases, income from the other sources (ag+nonag seasonal employment out of village, self-employment) must decrease. This is acceptable, as all informal off-farm income sources are treated as a single activity with a single wage rate in the model.  

## SAM balancing: Household incomes account for only 64-75% of household expenditures. In order to reduce the difference between receipts and payments of the household accounts, household income will be scaled up proportionally by multiplication with a household specific scaling factor.
# 1. Scale payments by the trgift account proportionally (# SAM balancing: the trgift account (which contains gifts and local transfers) has a surplus of about 25%. Assume that household expenses and receipts on these types of transfers are balanced within the village. Further, assume that households receive gifts and local transfers according to the proportions reported in the survey. Accordingly, scale up payments by trgift to households proportionally.). Rationale: The trgift account is the most unbalanced one, hence can accept a large part of the adjustment. The balancing of this account incorporates the assumption that the gifts are balanced within the village. 
 trgiftscal       <- 1.0 * 1.605045
# 2. Scale all income proportionally
 incscalhlmhi <- 1.0 * 2.125727 #Scaling factor to scale up all receipts of hlmhi
 incscalhlmmd <- 1.0 * 1.492    #Scaling factor to scale up all receipts of hlmmd
 incscalhlmlo <- 1.0 * 1.64043  #Scaling factor to scale up all receipts of hlmlo
 incscalhhmhi <- 1.0 * 1.617283 #Scaling factor to scale up all receipts of hhmhi
 incscalhhmmd <- 1.0 * 1.980247 #Scaling factor to scale up all receipts of hhmmd
 incscalhhmlo <- 1.0 * 1.83958  #Scaling factor to scale up all receipts of hhmlo

## SAM balancing: Due to the scaling of household income, the flab**of accounts become unbalanced. Scale up payments by awage to flab**of to match expenses of the factors. As a consequence, also scale up receipts by awage accordingly. This is done by multiplication of the payments from the activities to the factors with the household income scaling factors. Furthermore, receipts by the activities from outvill have to be adjusted. This happens through a change in the code. Now, instead of adding all income from wages, the respective cell is filled with the sum of the payments of the activities.

## SAM balancing: Scale up payments by the agricultural activities of each household proportionally to minimize the sum of squared differences for each factor account for each household. This is done via multiplying again the aginpscal** multipliers above

## SAM balancing: After minimizing the sum of squared differences, scale payments by intermediate inputs / capital to outvill to balance the commodity accounts. This is done via changes in the code in a way that imports are automatically set equal to the total demand. 

## SAM balancing: After minimizing the absolute differences, scale receipts by agr. activities to balance the activity accounts. This happens via multiplication with the respective aagrpayscal**.

 agrpayscal11 <- 1.0 * 1.6413
 agrpayscal12 <- 1.0 * 1.7211
 agrpayscal13 <- 1.0 * 1.6199
 agrpayscal21 <- 1.0 * 1.7669
 agrpayscal22 <- 1.0 * 2.31221	
 agrpayscal23 <- 1.0 * 1.9821

## SAM balancing: The last operation leaves the agr. commodity account unbalanced. Most ideally, one might wish to scale up only the payments from outvill to the agr. commodity to balance the accounts. However, due to the high share of eslf-consumption, this would require to scale up receipts from outvill disproportionately high. This would distort the ratio of sales and self-consumption of the households. Scaling self-consumption of the households by the same factor, however, would distort the relative budget shares of the self.consumed vs. purchased commodities. The choice made here is scale the payments from outvill disproportionally higher, thus distorting both shares a little but less than when scaling either only payments from outvill or both payments from outvill and self-consumption.
## The scaling is done via the definition of two scaling factors, one of which depends on the otherK
 cagrecscal  <- 1.0 * 1.869543
 agrselfscal <- cagrecscal * 0.95

## SAM balancing: Scale receipts of blood sales to match payments. This is done via a change in the code: Receipts of ablood from outvill are expressed as the sum of the payments.

# The consequence is a new deficit of the households due to the increased self-consumption. This deficit, however, is much lower as compared to the initial deficit. Expenses on average make up 110 % of income (as compared to over 200% at the beginning). For the final correction it is assumed that expenses on everything except self-consumption and leisure are too high. They are scaled down to balance the household accounts. 
 expscalhlmhi <- 1.0 * 0.892785
 expscalhlmmd <- 1.0 * 0.80833
 expscalhlmlo <- 1.0 * 0.74737
 expscalhhmhi <- 1.0 * 0.82842
 expscalhhmmd <- 1.0 * 0.789611 #*  0.787303# 0.820619 
 expscalhhmlo <- 1.0 * 0.77481 

# Result: Household accounts are balanced but receipts of the consumed (and imported) commodity accounts are too low. Remedy: reduce payments by commodities to outvill account. This, again, is done via a change in the code, expressing payments from the commodities to outvill as the sum of receipts of the respective commodities. 

# Result: A SAM in which all but seven accounts are balanced. The still not completely balanced accounts are the flab***f accounts, the land factor accounts, and the outvill account. On average, the absolute differences between receipts and payments of the unbalanced accounts account for 4,70% of the payments of the accounts. Hence, the manual balancing process carried out has left a rather balanced SAM from which the most extreme imbalances have been purged. In a final step, the remaining imbalances are will be removed.

# Final balancing step: All in all, the accounts which remain imbalanced have a sum of excess receipts of 44025 (all imbalanced accounts except the outvill account) and a sum of excess payments of -44034 (in the outvill account). As all the accounts with excess receipts pay to the household accounts we use the cells which contain the respective payments to the household to balance the accounts. Payments from the respective accounts to the households are decreased proportionally. Again, the procedure results in a decrease in household income. Consequently, household expenditures and the corresponding payments by commodities out of the village are adjusted again to accomodate the changes in income. 

# Scale payments by the farm labor accounts proportionally
 flabmadfscal2    <- 1.0 * 1.034237534	
 flabmecfscal2    <- 1.0 * 1.050431622
 flabfemadfscal2  <- 1.0 * 1.0292461551	
 flabfemecfscal2  <- 1.0 * 1.0572414785
# Scale payments by land accounts proportionally
 flndirrscal2     <- 1.0 * 1.02898686973144
 flndnirrscal2    <- 1.0 * 1.08328615922392

# Scale households' expenditures on all goods except leisure, self-consumed goods, transfers (trgift and trshock) and savings (sisi) to match new income
 expscalhlmhi2    <- 1.0 * 1.02473
 expscalhlmmd2    <- 1.0 * 1.04162
 expscalhlmlo2    <- 1.0 * 1.05929
 expscalhhmhi2    <- 1.0 * 1.0306
 expscalhhmmd2    <- 1.0 * 1.053163
 expscalhhmlo2    <- 1.0 * 1.0692
# Note that the payments from purchased commodities to outvill again are adjusted automatically

# The SAM is now balanced.
# Unfortunately, the rounding has left some accounts slightly unbalanced, mostly by a value of 1, at most by 3. Change this arbitrarily by adding or substracting the difference.
# Now the SAM is REALLY balanced!!!

#######
#### SAM COMPILATION
#######

## 1. HOUSEHOLD SUPPLY OF AGRICULTURAL ACTIVITIES
# Maize
 agrsalagg <- aggregate((corninc+maizeinc+rapeinc+oilinc+riceinc+paddyinc+ograininc+ocropinc+veginc+fruitinc+piginc+cowinc+poultryinc+egginc+oanimalinc+forestryinc+fisheryinc+rentinc+processinc+otherinc.x),by=list(RHG),FUN=sum)
 SAMmatrix["aagrlmhi ","cagr "] <- agrsalagg$x[1] * agrpayscal11
 SAMmatrix["aagrlmmd ","cagr "] <- agrsalagg$x[2] * agrpayscal12
 SAMmatrix["aagrlmlo ","cagr "] <- agrsalagg$x[3] * agrpayscal13
 SAMmatrix["aagrhmhi ","cagr "] <- agrsalagg$x[4] * agrpayscal21
 SAMmatrix["aagrhmmd ","cagr "] <- agrsalagg$x[5] * agrpayscal22
 SAMmatrix["aagrhmlo ","cagr "] <- agrsalagg$x[6] * agrpayscal23

## 2. DEMAND FOR VILLAGE TRADED LAND BY AGRICULTURAL ACTIVITIES

 agrlndirragg <- aggregate(irrrentlandval,by=list(RHG),FUN=sum)
 SAMmatrix["clndirr ","aagrlmhi "]  <- agrlndirragg$x[1] * aginpscal11 
 SAMmatrix["clndirr ","aagrlmmd "]  <- agrlndirragg$x[2] * aginpscal12
 SAMmatrix["clndirr ","aagrlmlo "]  <- agrlndirragg$x[3] * aginpscal13
 SAMmatrix["clndirr ","aagrhmhi "]  <- agrlndirragg$x[4] * aginpscal21 
 SAMmatrix["clndirr ","aagrhmmd "]  <- agrlndirragg$x[5] * aginpscal22 
 SAMmatrix["clndirr ","aagrhmlo "]  <- agrlndirragg$x[6] * aginpscal23

 agrlndnirragg <- aggregate(nonirrrentlandval,by=list(RHG),FUN=sum)
 SAMmatrix["clndnirr ","aagrlmhi "]  <- agrlndnirragg$x[1] * aginpscal11 + 2
 SAMmatrix["clndnirr ","aagrlmmd "]  <- agrlndnirragg$x[2] * aginpscal12
 SAMmatrix["clndnirr ","aagrlmlo "]  <- agrlndnirragg$x[3] * aginpscal13
 SAMmatrix["clndnirr ","aagrhmhi "]  <- agrlndnirragg$x[4] * aginpscal21
 SAMmatrix["clndnirr ","aagrhmmd "]  <- agrlndnirragg$x[5] * aginpscal22
 SAMmatrix["clndnirr ","aagrhmlo "]  <- agrlndnirragg$x[6] * aginpscal23

## 3. INCOME FROM LAND RENTALS (payment from commodity to activity (clndirr und	clndnirr to flndirr and flndnonirr)
#SAM balancing: Scaling of input use by agr. activities requires scaling of payments from land commodity to factors. To make matter simple, write payments as to factor accounts simply as the sum of receipts of the commodity-

 SAMmatrix["flndirr ","clndirr "]   <- sum(SAMmatrix["clndirr ",])  * aginpscal 
 SAMmatrix["flndnirr ","clndnirr "] <- sum(SAMmatrix["clndnirr ",]) * aginpscal -2

## 4. DEMAND FOR LOCAL AGRICULTURAL HIRED LABOR
## SAM balancing:  Recompute input use of agricultural activities according to the newly computed cost shares (see above)

agrlabagvilagg <- aggregate(lochirlabval,by=list(RHG),FUN=sum)
 SAMmatrix["clabagvil ","aagrlmhi "]  <- agrlabagvilagg$x[1] * aginpscal11 
 SAMmatrix["clabagvil ","aagrlmmd "]  <- agrlabagvilagg$x[2] * aginpscal12 
 SAMmatrix["clabagvil ","aagrlmlo "]  <- agrlabagvilagg$x[3] * aginpscal13 
 SAMmatrix["clabagvil ","aagrhmhi "]  <- agrlabagvilagg$x[4] * aginpscal21 
 SAMmatrix["clabagvil ","aagrhmmd "]  <- agrlabagvilagg$x[5] * aginpscal22 
 SAMmatrix["clabagvil ","aagrhmlo "]  <- agrlabagvilagg$x[6] * aginpscal23

## 5. INTERMEDIATE AND CAPITAL INPUT DEMAND FROM AGRICULTURE

agrureaagg <- aggregate(ureaval,by=list(RHG),FUN=sum)
 SAMmatrix["curea ","aagrlmhi "]  <- agrureaagg$x[1] * aginpscal11 
 SAMmatrix["curea ","aagrlmmd "]  <- agrureaagg$x[2] * aginpscal12 + 3
 SAMmatrix["curea ","aagrlmlo "]  <- agrureaagg$x[3] * aginpscal13
 SAMmatrix["curea ","aagrhmhi "]  <- agrureaagg$x[4] * aginpscal21 + 3
 SAMmatrix["curea ","aagrhmmd "]  <- agrureaagg$x[5] * aginpscal22 - 1
 SAMmatrix["curea ","aagrhmlo "]  <- agrureaagg$x[6] * aginpscal23 - 4

agrpestagg <- aggregate(pestval,by=list(RHG),FUN=sum)
 SAMmatrix["cpest ","aagrlmhi "]  <- agrpestagg$x[1] * aginpscal11 
 SAMmatrix["cpest ","aagrlmmd "]  <- agrpestagg$x[2] * aginpscal12
 SAMmatrix["cpest ","aagrlmlo "]  <- agrpestagg$x[3] * aginpscal13
 SAMmatrix["cpest ","aagrhmhi "]  <- agrpestagg$x[4] * aginpscal21 
 SAMmatrix["cpest ","aagrhmmd "]  <- agrpestagg$x[5] * aginpscal22 
 SAMmatrix["cpest ","aagrhmlo "]  <- agrpestagg$x[6] * aginpscal23

agrfertagg <- aggregate(fertval,by=list(RHG),FUN=sum)
 SAMmatrix["cfert ","aagrlmhi "]  <- agrfertagg$x[1] * aginpscal11 
 SAMmatrix["cfert ","aagrlmmd "]  <- agrfertagg$x[2] * aginpscal12
 SAMmatrix["cfert ","aagrlmlo "]  <- agrfertagg$x[3] * aginpscal13
 SAMmatrix["cfert ","aagrhmhi "]  <- agrfertagg$x[4] * aginpscal21 
 SAMmatrix["cfert ","aagrhmmd "]  <- agrfertagg$x[5] * aginpscal22 
 SAMmatrix["cfert ","aagrhmlo "]  <- agrfertagg$x[6] * aginpscal23

agrseedagg <- aggregate((seedmaizvc+seedmaizvk+seedrapevc+seedrapevk+seedricevc+seedricevk+seedocrpvc+seedocrpvk+seedvegtvc+seedvegtvk),by=list(RHG),FUN=sum)
 SAMmatrix["cseed ","aagrlmhi "]  <- agrseedagg$x[1] * aginpscal11 
 SAMmatrix["cseed ","aagrlmmd "]  <- agrseedagg$x[2] * aginpscal12
 SAMmatrix["cseed ","aagrlmlo "]  <- agrseedagg$x[3] * aginpscal13
 SAMmatrix["cseed ","aagrhmhi "]  <- agrseedagg$x[4] * aginpscal21
 SAMmatrix["cseed ","aagrhmmd "]  <- agrseedagg$x[5] * aginpscal22
 SAMmatrix["cseed ","aagrhmlo "]  <- agrseedagg$x[6] * aginpscal23

agrfeedagg <- aggregate(feedval,by=list(RHG),FUN=sum)
 SAMmatrix["cfeed ","aagrlmhi "]  <- agrfeedagg$x[1] * aginpscal11 
 SAMmatrix["cfeed ","aagrlmmd "]  <- agrfeedagg$x[2] * aginpscal12
 SAMmatrix["cfeed ","aagrlmlo "]  <- agrfeedagg$x[3] * aginpscal13
 SAMmatrix["cfeed ","aagrhmhi "]  <- agrfeedagg$x[4] * aginpscal21
 SAMmatrix["cfeed ","aagrhmmd "]  <- agrfeedagg$x[5] * aginpscal22
 SAMmatrix["cfeed ","aagrhmlo "]  <- agrfeedagg$x[6] * aginpscal23

agrlvstrpagg <- aggregate(breedlvskval,by=list(RHG),FUN=sum)
 SAMmatrix["clvstrp ","aagrlmhi "]  <- agrlvstrpagg$x[1] * aginpscal11
 SAMmatrix["clvstrp ","aagrlmmd "]  <- agrlvstrpagg$x[2] * aginpscal12
 SAMmatrix["clvstrp ","aagrlmlo "]  <- agrlvstrpagg$x[3] * aginpscal13
 SAMmatrix["clvstrp ","aagrhmhi "]  <- agrlvstrpagg$x[4] * aginpscal21
 SAMmatrix["clvstrp ","aagrhmmd "]  <- agrlvstrpagg$x[5] * aginpscal22
 SAMmatrix["clvstrp ","aagrhmlo "]  <- agrlvstrpagg$x[6] * aginpscal23

agrvetagg <- aggregate(veterval,by=list(RHG),FUN=sum)
 SAMmatrix["cvet ","aagrlmhi "]  <- agrvetagg$x[1] * aginpscal11
 SAMmatrix["cvet ","aagrlmmd "]  <- agrvetagg$x[2] * aginpscal12
 SAMmatrix["cvet ","aagrlmlo "]  <- agrvetagg$x[3] * aginpscal13
 SAMmatrix["cvet ","aagrhmhi "]  <- agrvetagg$x[4] * aginpscal21
 SAMmatrix["cvet ","aagrhmmd "]  <- agrvetagg$x[5] * aginpscal22
 SAMmatrix["cvet ","aagrhmlo "]  <- agrvetagg$x[6] * aginpscal23

agrlabhiragg <- aggregate(hirlabval,by=list(RHG),FUN=sum)
 SAMmatrix["clabhir ","aagrlmhi "]  <- agrlabhiragg$x[1] * aginpscal11 
 SAMmatrix["clabhir ","aagrlmmd "]  <- agrlabhiragg$x[2] * aginpscal12
 SAMmatrix["clabhir ","aagrlmlo "]  <- agrlabhiragg$x[3] * aginpscal13
 SAMmatrix["clabhir ","aagrhmhi "]  <- agrlabhiragg$x[4] * aginpscal21
 SAMmatrix["clabhir ","aagrhmmd "]  <- agrlabhiragg$x[5] * aginpscal22
 SAMmatrix["clabhir ","aagrhmlo "]  <- agrlabhiragg$x[6] * aginpscal23

agrmachagg <- aggregate(machval,by=list(RHG),FUN=sum)
 SAMmatrix["cmach ","aagrlmhi "]  <- agrmachagg$x[1] * aginpscal11
 SAMmatrix["cmach ","aagrlmmd "]  <- agrmachagg$x[2] * aginpscal12
 SAMmatrix["cmach ","aagrlmlo "]  <- agrmachagg$x[3] * aginpscal13
 SAMmatrix["cmach ","aagrhmhi "]  <- agrmachagg$x[4] * aginpscal21
 SAMmatrix["cmach ","aagrhmmd "]  <- agrmachagg$x[5] * aginpscal22
 SAMmatrix["cmach ","aagrhmlo "]  <- agrmachagg$x[6] * aginpscal23

agrlabhiragg <- aggregate(hirlabval,by=list(RHG),FUN=sum)
 SAMmatrix["clabhir ","aagrlmhi "]  <- agrlabhiragg$x[1] * aginpscal11 
 SAMmatrix["clabhir ","aagrlmmd "]  <- agrlabhiragg$x[2] * aginpscal12
 SAMmatrix["clabhir ","aagrlmlo "]  <- agrlabhiragg$x[3] * aginpscal13
 SAMmatrix["clabhir ","aagrhmhi "]  <- agrlabhiragg$x[4] * aginpscal21
 SAMmatrix["clabhir ","aagrhmmd "]  <- agrlabhiragg$x[5] * aginpscal22
 SAMmatrix["clabhir ","aagrhmlo "]  <- agrlabhiragg$x[6] * aginpscal23

agrswatagg <- aggregate(irrval,by=list(RHG),FUN=sum)
 SAMmatrix["cswat ","aagrlmhi "]  <- agrswatagg$x[1] * aginpscal11 
 SAMmatrix["cswat ","aagrlmmd "]  <- agrswatagg$x[2] * aginpscal12 
 SAMmatrix["cswat ","aagrlmlo "]  <- agrswatagg$x[3] * aginpscal13
 SAMmatrix["cswat ","aagrhmhi "]  <- agrswatagg$x[4] * aginpscal21
 SAMmatrix["cswat ","aagrhmmd "]  <- agrswatagg$x[5] * aginpscal22
 SAMmatrix["cswat ","aagrhmlo "]  <- agrswatagg$x[6] * aginpscal23

agrseneragg <- aggregate(gasval,by=list(RHG),FUN=sum)
 SAMmatrix["csener ","aagrlmhi "]  <- agrseneragg$x[1] * aginpscal11
 SAMmatrix["csener ","aagrlmmd "]  <- agrseneragg$x[2] * aginpscal12
 SAMmatrix["csener ","aagrlmlo "]  <- agrseneragg$x[3] * aginpscal13
 SAMmatrix["csener ","aagrhmhi "]  <- agrseneragg$x[4] * aginpscal21
 SAMmatrix["csener ","aagrhmmd "]  <- agrseneragg$x[5] * aginpscal22
 SAMmatrix["csener ","aagrhmlo "]  <- agrseneragg$x[6] * aginpscal23
 
## 6. CAPITAL / INTERMEDIATE IMPORTS

 SAMmatrix["outvill ","curea "]    <- sum(SAMmatrix["curea ",]) - 1
 SAMmatrix["outvill ","cpest "]    <- sum(SAMmatrix["cpest ",]) + 1
 SAMmatrix["outvill ","cfert "]    <- sum(SAMmatrix["cfert ",])
 SAMmatrix["outvill ","cseed "]    <- sum(SAMmatrix["cseed ",]) + 2
 SAMmatrix["outvill ","cfeed "]    <- sum(SAMmatrix["cfeed ",])
 SAMmatrix["outvill ","clvstrp "]  <- sum(SAMmatrix["clvstrp ",]) + 1
 SAMmatrix["outvill ","cvet "]     <- sum(SAMmatrix["cvet ",])
 SAMmatrix["outvill ","cmach "]    <- sum(SAMmatrix["cmach ",]) + 1
 SAMmatrix["outvill ","clabhir "]  <- sum(SAMmatrix["clabhir ",]) + 1

## 7. FACTOR DEMAND FROM AGRICULTURE - Household labor
# SAM balancing: Recompute input use of agricultural activities according to the newly computed cost shares (see above)

agrlabmadfagg <- aggregate(farmalelabval+orchmalelabval+animmalelabval+fisherymalelabval,by=list(RHG),FUN=sum)
 SAMmatrix["flabmadf ","aagrlmhi "]  <- agrlabmadfagg$x[1] * aginpscal11 
 SAMmatrix["flabmadf ","aagrlmmd "]  <- agrlabmadfagg$x[2] * aginpscal12
 SAMmatrix["flabmadf ","aagrlmlo "]  <- agrlabmadfagg$x[3] * aginpscal13
 SAMmatrix["flabmadf ","aagrhmhi "]  <- agrlabmadfagg$x[4] * aginpscal21
 SAMmatrix["flabmadf ","aagrhmmd "]  <- agrlabmadfagg$x[5] * aginpscal22
 SAMmatrix["flabmadf ","aagrhmlo "]  <- agrlabmadfagg$x[6] * aginpscal23

agrlabmecfagg <- aggregate(farmaleeldlabval+orchmaleeldlabval+animmaleeldlabval+fisherymaleeldlabval+farmalechildlabval+orchmalechildlabval+animmalechildlabval+fisherymalechildlabval,by=list(RHG),FUN=sum)
 SAMmatrix["flabmecf ","aagrlmhi "]  <- agrlabmecfagg$x[1] * aginpscal11
 SAMmatrix["flabmecf ","aagrlmmd "]  <- agrlabmecfagg$x[2] * aginpscal12
 SAMmatrix["flabmecf ","aagrlmlo "]  <- agrlabmecfagg$x[3] * aginpscal13
 SAMmatrix["flabmecf ","aagrhmhi "]  <- agrlabmecfagg$x[4] * aginpscal21
 SAMmatrix["flabmecf ","aagrhmmd "]  <- agrlabmecfagg$x[5] * aginpscal22
 SAMmatrix["flabmecf ","aagrhmlo "]  <- agrlabmecfagg$x[6] * aginpscal23

agrlabfemadfagg <- aggregate(farfemlabval+orchfemlabval+animfemlabval+fisheryfemlabval,by=list(RHG),FUN=sum)
 SAMmatrix["flabfemadf ","aagrlmhi "]  <- agrlabfemadfagg$x[1] * aginpscal11
 SAMmatrix["flabfemadf ","aagrlmmd "]  <- agrlabfemadfagg$x[2] * aginpscal12
 SAMmatrix["flabfemadf ","aagrlmlo "]  <- agrlabfemadfagg$x[3] * aginpscal13
 SAMmatrix["flabfemadf ","aagrhmhi "]  <- agrlabfemadfagg$x[4] * aginpscal21
 SAMmatrix["flabfemadf ","aagrhmmd "]  <- agrlabfemadfagg$x[5] * aginpscal22
 SAMmatrix["flabfemadf ","aagrhmlo "]  <- agrlabfemadfagg$x[6] * aginpscal23

agrlabfemecfagg <- aggregate(farfemeldlabval+orchfemeldlabval+animfemeldlabval+fisheryfemeldlabval+farfemchildlabval+orchfemchildlabval+animfemchildlabval+fisheryfemchildlabval,by=list(RHG),FUN=sum)
 SAMmatrix["flabfemecf ","aagrlmhi "]  <- agrlabfemecfagg$x[1] * aginpscal11
 SAMmatrix["flabfemecf ","aagrlmmd "]  <- agrlabfemecfagg$x[2] * aginpscal12
 SAMmatrix["flabfemecf ","aagrlmlo "]  <- agrlabfemecfagg$x[3] * aginpscal13
 SAMmatrix["flabfemecf ","aagrhmhi "]  <- agrlabfemecfagg$x[4] * aginpscal21
 SAMmatrix["flabfemecf ","aagrhmmd "]  <- agrlabfemecfagg$x[5] * aginpscal22
 SAMmatrix["flabfemecf ","aagrhmlo "]  <- agrlabfemecfagg$x[6] * aginpscal23
 
## 9. FACTOR DEMAND FROM AGRICULTURE - Contract land
# SAM balancing: Recompute input use of agricultural activities according to the newly computed cost shares (see above)

agrlndirragg <- aggregate(irrlandval,by=list(RHG),FUN=sum)
 SAMmatrix["flndirr ","aagrlmhi "]  <- agrlndirragg$x[1] * aginpscal11 
 SAMmatrix["flndirr ","aagrlmmd "]  <- agrlndirragg$x[2] * aginpscal12
 SAMmatrix["flndirr ","aagrlmlo "]  <- agrlndirragg$x[3] * aginpscal13
 SAMmatrix["flndirr ","aagrhmhi "]  <- agrlndirragg$x[4] * aginpscal21
 SAMmatrix["flndirr ","aagrhmmd "]  <- agrlndirragg$x[5] * aginpscal22
 SAMmatrix["flndirr ","aagrhmlo "]  <- agrlndirragg$x[6] * aginpscal23

agrlndnirragg <- aggregate(nonirrlandval,by=list(RHG),FUN=sum)
 SAMmatrix["flndnirr ","aagrlmhi "]  <- agrlndnirragg$x[1] * aginpscal11
 SAMmatrix["flndnirr ","aagrlmmd "]  <- agrlndnirragg$x[2] * aginpscal12
 SAMmatrix["flndnirr ","aagrlmlo "]  <- agrlndnirragg$x[3] * aginpscal13
 SAMmatrix["flndnirr ","aagrhmhi "]  <- agrlndnirragg$x[4] * aginpscal21
 SAMmatrix["flndnirr ","aagrhmmd "]  <- agrlndnirragg$x[5] * aginpscal22
 SAMmatrix["flndnirr ","aagrhmlo "]  <- agrlndnirragg$x[6] * aginpscal23

## 10. HOUSEHOLD INCOME - Blood sales

 bloodagg <- aggregate(blood,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","abloodlmhi "] <- bloodagg$x[1] * incscalhlmhi
 SAMmatrix["hlmmd ","abloodlmmd "] <- bloodagg$x[2] * incscalhlmmd
 SAMmatrix["hlmlo ","abloodlmlo "] <- bloodagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","abloodhmhi "] <- bloodagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","abloodhmmd "] <- bloodagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","abloodhmlo "] <- bloodagg$x[6] * incscalhhmlo

## 11. HOUSEHOLD INCOME - Factor returns: Agricultural labor
# SAM balancing: The scaling of factor use has distorted receipts and payments of the agricultural labor factors slightly. Although accounts are balanced, total receipts of each single factor do not add up to toal expenses. Correct this manually by adding and substracting the corresponding values. 
# Male adult labor:
 totmalelabagr <- farmalelabval + orchmalelabval + animmalelabval + fisherymalelabval
 malelabagragg <- aggregate(totmalelabagr,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmadf "] <- malelabagragg$x[1] * flabmadfscal * incscalhlmhi * flabmadfscal2 + 506
 SAMmatrix["hlmmd ","flabmadf "] <- malelabagragg$x[2] * flabmadfscal * incscalhlmmd * flabmadfscal2 + 469
 SAMmatrix["hlmlo ","flabmadf "] <- malelabagragg$x[3] * flabmadfscal * incscalhlmlo * flabmadfscal2 - 247
 SAMmatrix["hhmhi ","flabmadf "] <- malelabagragg$x[4] * flabmadfscal * incscalhhmhi * flabmadfscal2 - 116
 SAMmatrix["hhmmd ","flabmadf "] <- malelabagragg$x[5] * flabmadfscal * incscalhhmmd * flabmadfscal2 - 696
 SAMmatrix["hhmlo ","flabmadf "] <- malelabagragg$x[6] * flabmadfscal * incscalhhmlo * flabmadfscal2 + 84
# Male elder and child  labor
 totmaleclabagr <- farmaleeldlabval + orchmaleeldlabval + animmaleeldlabval + fisherymaleeldlabval +
                     farmalechildlabval + orchmalechildlabval + animmalechildlabval + fisherymalechildlabval 
  maleclabagragg <- aggregate(totmaleclabagr,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmecf "] <- maleclabagragg$x[1] * flabmecfscal * incscalhlmhi * flabmecfscal2 + 18
 SAMmatrix["hlmmd ","flabmecf "] <- maleclabagragg$x[2] * flabmecfscal * incscalhlmmd * flabmecfscal2 + 109
 SAMmatrix["hlmlo ","flabmecf "] <- maleclabagragg$x[3] * flabmecfscal * incscalhlmlo * flabmecfscal2 - 83
 SAMmatrix["hhmhi ","flabmecf "] <- maleclabagragg$x[4] * flabmecfscal * incscalhhmhi * flabmecfscal2 - 13
 SAMmatrix["hhmmd ","flabmecf "] <- maleclabagragg$x[5] * flabmecfscal * incscalhhmmd * flabmecfscal2 - 32
 SAMmatrix["hhmlo ","flabmecf "] <- maleclabagragg$x[6] * flabmecfscal * incscalhhmlo * flabmecfscal2

# Female adult labor:
 totfemlabagr <- farfemlabval + orchfemlabval + animfemlabval + fisheryfemlabval
 femlabagragg <- aggregate(totfemlabagr,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemadf "] <- femlabagragg$x[1] * flabfemadfscal * incscalhlmhi * flabfemadfscal2 + 69
 SAMmatrix["hlmmd ","flabfemadf "] <- femlabagragg$x[2] * flabfemadfscal * incscalhlmmd * flabfemadfscal2 + 54 
 SAMmatrix["hlmlo ","flabfemadf "] <- femlabagragg$x[3] * flabfemadfscal * incscalhlmlo * flabfemadfscal2 - 29
 SAMmatrix["hhmhi ","flabfemadf "] <- femlabagragg$x[4] * flabfemadfscal * incscalhhmhi * flabfemadfscal2 - 17
 SAMmatrix["hhmmd ","flabfemadf "] <- femlabagragg$x[5] * flabfemadfscal * incscalhhmmd * flabfemadfscal2 - 86
 SAMmatrix["hhmlo ","flabfemadf "] <- femlabagragg$x[6] * flabfemadfscal * incscalhhmlo * flabfemadfscal2 + 8
# Female elder and child  labor
 totfemclabagr <- farfemeldlabval + orchfemeldlabval + animfemeldlabval + fisheryfemeldlabval +
                    farfemchildlabval + orchfemchildlabval + animfemchildlabval + fisheryfemchildlabval               
  femclabagragg <- aggregate(totfemclabagr,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemecf "] <- femclabagragg$x[1] * flabfemecfscal * incscalhlmhi * flabfemecfscal2 + 13
 SAMmatrix["hlmmd ","flabfemecf "] <- femclabagragg$x[2] * flabfemecfscal * incscalhlmmd * flabfemecfscal2 + 75
 SAMmatrix["hlmlo ","flabfemecf "] <- femclabagragg$x[3] * flabfemecfscal * incscalhlmlo * flabfemecfscal2 - 49
 SAMmatrix["hhmhi ","flabfemecf "] <- femclabagragg$x[4] * flabfemecfscal * incscalhhmhi * flabfemecfscal2 - 17
 SAMmatrix["hhmmd ","flabfemecf "] <- femclabagragg$x[5] * flabfemecfscal * incscalhhmmd * flabfemecfscal2 - 21
 SAMmatrix["hhmlo ","flabfemecf "] <- femclabagragg$x[6] * flabfemecfscal * incscalhhmlo * flabfemecfscal2 - 3

## 12. HOUSEHOLD INCOME - Factor returns: Nonagricultural labor - profit version

## Local formal off-farm
#  Male adult labor

 wagehrmaladagg <- aggregate(wagehrmaladval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmadof "] <- wagehrmaladagg$x[1] * incscalhlmhi 
 SAMmatrix["hlmmd ","flabmadof "] <- wagehrmaladagg$x[2] * incscalhlmmd
 SAMmatrix["hlmlo ","flabmadof "] <- wagehrmaladagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","flabmadof "] <- (wagehrmaladagg$x[4]-4170) * incscalhhmhi 
 SAMmatrix["hhmmd ","flabmadof "] <- wagehrmaladagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabmadof "] <- wagehrmaladagg$x[6] * incscalhhmlo
#  Male elder and child labor
 wagehrmalecagg <- aggregate(wagehrmaleldval+wagehrmalchildval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmecof "] <- wagehrmalecagg$x[1] * incscalhlmhi
 SAMmatrix["hlmmd ","flabmecof "] <- wagehrmalecagg$x[2] * incscalhlmmd
 SAMmatrix["hlmlo ","flabmecof "] <- wagehrmalecagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","flabmecof "] <- wagehrmalecagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabmecof "] <- wagehrmalecagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabmecof "] <- wagehrmalecagg$x[6] * incscalhhmlo

#  Female adult labor
 wagehrfemadagg <- aggregate(wagehrfemadval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemadof "] <- wagehrfemadagg$x[1] * incscalhlmhi
 SAMmatrix["hlmmd ","flabfemadof "] <- wagehrfemadagg$x[2] * incscalhlmmd
 SAMmatrix["hlmlo ","flabfemadof "] <- wagehrfemadagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","flabfemadof "] <- wagehrfemadagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabfemadof "] <- wagehrfemadagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabfemadof "] <- wagehrfemadagg$x[6] * incscalhhmlo
#  Female elder and child labor
 wagehrfemecagg <- aggregate(wagehrfemeldval+wagehrfemchildval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemecof "] <- wagehrfemecagg$x[1] * incscalhlmhi
 SAMmatrix["hlmmd ","flabfemecof "] <- wagehrfemecagg$x[2] * incscalhlmmd
 SAMmatrix["hlmlo ","flabfemecof "] <- wagehrfemecagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","flabfemecof "] <- wagehrfemecagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabfemecof "] <- wagehrfemecagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabfemecof "] <- wagehrfemecagg$x[6] * incscalhhmlo

## Local informal off-farm
#  Male adult labor
 locinfmaladval <- oddjhrmaladval + selfemphrmaladval
 locinfmaladagg <- aggregate(locinfmaladval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmadoi "] <- (locinfmaladagg$x[1]+500) * incscalhlmhi
 SAMmatrix["hlmmd ","flabmadoi "] <- (locinfmaladagg$x[2]-2000) * incscalhlmmd
 SAMmatrix["hlmlo ","flabmadoi "] <- (locinfmaladagg$x[3]-1840) * incscalhlmlo
 SAMmatrix["hhmhi ","flabmadoi "] <- locinfmaladagg$x[4] * incscalhhmhi 
 SAMmatrix["hhmmd ","flabmadoi "] <- (locinfmaladagg$x[5]+100) * incscalhhmmd
 SAMmatrix["hhmlo ","flabmadoi "] <- locinfmaladagg$x[6] * incscalhhmlo
#  Male elder and child labor
 locinfmalecval <-  oddjhrmaleldval + selfemphrmalchildval
 locinfmalecagg <- aggregate(locinfmalecval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmecoi "] <- locinfmalecagg$x[1] * incscalhlmhi
 SAMmatrix["hlmmd ","flabmecoi "] <- locinfmalecagg$x[2] * incscalhlmmd 
 SAMmatrix["hlmlo ","flabmecoi "] <- locinfmalecagg$x[3] * incscalhlmlo 
 SAMmatrix["hhmhi ","flabmecoi "] <- locinfmalecagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabmecoi "] <- locinfmalecagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabmecoi "] <- locinfmalecagg$x[6] * incscalhhmlo
#  Female adult labor
 locinffemadval <-  oddjhrfemadval + selfemphrfemadval
 locinffemadagg <- aggregate(locinffemadval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemadoi "] <- locinffemadagg$x[1] * incscalhlmhi 
 SAMmatrix["hlmmd ","flabfemadoi "] <- locinffemadagg$x[2] * incscalhlmmd 
 SAMmatrix["hlmlo ","flabfemadoi "] <- locinffemadagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","flabfemadoi "] <- locinffemadagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabfemadoi "] <- locinffemadagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabfemadoi "] <- locinffemadagg$x[6] * incscalhhmlo
#  Female elder and child labor
 locinffemecval <- oddjhrfemeldval + selfemphrfemchildval
 locinffemecagg <- aggregate(locinffemecval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemecoi "] <- locinffemecagg$x[1] * incscalhlmhi 
 SAMmatrix["hlmmd ","flabfemecoi "] <- locinffemecagg$x[2] * incscalhlmmd 
 SAMmatrix["hlmlo ","flabfemecoi "] <- locinffemecagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","flabfemecoi "] <- locinffemecagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabfemecoi "] <- locinffemecagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabfemecoi "] <- locinffemecagg$x[6] * incscalhhmlo

## Remittances
#  Male adult labor
 migmaladval   <- mighrmaladval 
 mighrmaladagg <- aggregate(migmaladval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmadm "] <- mighrmaladagg$x[1] * incscalhlmhi 
 SAMmatrix["hlmmd ","flabmadm "] <- mighrmaladagg$x[2] * incscalhlmmd 
 SAMmatrix["hlmlo ","flabmadm "] <- mighrmaladagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","flabmadm "] <- mighrmaladagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabmadm "] <- mighrmaladagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabmadm "] <- mighrmaladagg$x[6] * incscalhhmlo
#  Male elder and child labor
 migmalecval   <- mighrmaleldval +  mighrmalchildval 
 mighrmalecagg <- aggregate(migmalecval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmecm "] <- mighrmalecagg$x[1] * incscalhlmhi 
 SAMmatrix["hlmmd ","flabmecm "] <- mighrmalecagg$x[2] * incscalhlmmd 
 SAMmatrix["hlmlo ","flabmecm "] <- mighrmalecagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","flabmecm "] <- mighrmalecagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabmecm "] <- mighrmalecagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabmecm "] <- mighrmalecagg$x[6] * incscalhhmlo
#  Female adult labor
 migfemadval   <- mighrfemadval 
 mighrfemadagg <- aggregate(migfemadval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemadm "] <- mighrfemadagg$x[1] * incscalhlmhi 
 SAMmatrix["hlmmd ","flabfemadm "] <- mighrfemadagg$x[2] * incscalhlmmd 
 SAMmatrix["hlmlo ","flabfemadm "] <- mighrfemadagg$x[3] * incscalhlmlo 
 SAMmatrix["hhmhi ","flabfemadm "] <- mighrfemadagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabfemadm "] <- mighrfemadagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabfemadm "] <- mighrfemadagg$x[6] * incscalhhmlo
#  Female elder and child  labor
 migfemecval   <- mighrfemeldval + mighrfemchildval 
 mighrfemecagg <- aggregate(migfemecval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemecm "] <- mighrfemecagg$x[1] * incscalhlmhi 
 SAMmatrix["hlmmd ","flabfemecm "] <- mighrfemecagg$x[2] * incscalhlmmd 
 SAMmatrix["hlmlo ","flabfemecm "] <- mighrfemecagg$x[3] * incscalhlmlo 
 SAMmatrix["hhmhi ","flabfemecm "] <- mighrfemecagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","flabfemecm "] <- mighrfemecagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","flabfemecm "] <- mighrfemecagg$x[6] * incscalhhmlo

## 13. HOUSEHOLD INCOME - Factor returns: Leisure - nonprofit version

## Local formal off-farm
#  Male adult labor
 maladleisagg <- aggregate(leishrmaladval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmadl "] <- maladleisagg$x[1]
 SAMmatrix["hlmmd ","flabmadl "] <- maladleisagg$x[2]
 SAMmatrix["hlmlo ","flabmadl "] <- maladleisagg$x[3]
 SAMmatrix["hhmhi ","flabmadl "] <- maladleisagg$x[4]
 SAMmatrix["hhmmd ","flabmadl "] <- maladleisagg$x[5]
 SAMmatrix["hhmlo ","flabmadl "] <- maladleisagg$x[6]
#  Male elder and child labor
 malecleisagg <- aggregate(leishrmaleldval+leishrmalchildval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabmecl "] <- malecleisagg$x[1]
 SAMmatrix["hlmmd ","flabmecl "] <- malecleisagg$x[2]
 SAMmatrix["hlmlo ","flabmecl "] <- malecleisagg$x[3]
 SAMmatrix["hhmhi ","flabmecl "] <- malecleisagg$x[4]
 SAMmatrix["hhmmd ","flabmecl "] <- malecleisagg$x[5]
 SAMmatrix["hhmlo ","flabmecl "] <- malecleisagg$x[6]
#  Female adult labor
 femadleisagg <- aggregate(leishrfemadval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemadl "] <- femadleisagg$x[1]
 SAMmatrix["hlmmd ","flabfemadl "] <- femadleisagg$x[2]
 SAMmatrix["hlmlo ","flabfemadl "] <- femadleisagg$x[3]
 SAMmatrix["hhmhi ","flabfemadl "] <- femadleisagg$x[4]
 SAMmatrix["hhmmd ","flabfemadl "] <- femadleisagg$x[5]
 SAMmatrix["hhmlo ","flabfemadl "] <- femadleisagg$x[6]
#  Female elder and child labor
 femecleisagg <- aggregate(leishrfemeldval+leishrfemchildval,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flabfemecl "] <- femecleisagg$x[1]
 SAMmatrix["hlmmd ","flabfemecl "] <- femecleisagg$x[2]
 SAMmatrix["hlmlo ","flabfemecl "] <- femecleisagg$x[3]
 SAMmatrix["hhmhi ","flabfemecl "] <- femecleisagg$x[4]
 SAMmatrix["hhmmd ","flabfemecl "] <- femecleisagg$x[5]
 SAMmatrix["hhmlo ","flabfemecl "] <- femecleisagg$x[6]

## 13. FACTOR DEMAND FROM OFF-FARM ACTIVITIES - Household labor
# SAM balancing: In order to keep the account balanced, payments from activities to factors is scaled by the household income scaling factors.

 wagelabmadagg <- aggregate(wagehrmaladval,by=list(RHG),FUN=sum)
  SAMmatrix["flabmadof ","aoffflmhi "] <- wagelabmadagg$x[1] * incscalhlmhi
  SAMmatrix["flabmadof ","aoffflmmd "] <- wagelabmadagg$x[2] * incscalhlmmd
  SAMmatrix["flabmadof ","aoffflmlo "] <- wagelabmadagg$x[3] * incscalhlmlo
# SAMmatrix["flabmadof ","aofffhmhi "] <- wagelabmadagg$x[4] 
  SAMmatrix["flabmadof ","aofffhmhi "] <- 365 * incscalhhmhi
  SAMmatrix["flabmadof ","aofffhmmd "] <- wagelabmadagg$x[5] * incscalhhmmd
  SAMmatrix["flabmadof ","aofffhmlo "] <- wagelabmadagg$x[6] * incscalhhmlo
 wagelabmecagg <- aggregate(wagehrmaleldval+wagehrmalchildval,by=list(RHG),FUN=sum)
  SAMmatrix["flabmecof ","aoffflmhi "] <- wagelabmecagg$x[1] * incscalhlmhi
  SAMmatrix["flabmecof ","aoffflmmd "] <- wagelabmecagg$x[2] * incscalhlmmd
  SAMmatrix["flabmecof ","aoffflmlo "] <- wagelabmecagg$x[3] * incscalhlmlo
  SAMmatrix["flabmecof ","aofffhmhi "] <- wagelabmecagg$x[4] * incscalhhmhi
  SAMmatrix["flabmecof ","aofffhmmd "] <- wagelabmecagg$x[5] * incscalhhmmd
  SAMmatrix["flabmecof ","aofffhmlo "] <- wagelabmecagg$x[6] * incscalhhmlo
 wagelabfemadagg <- aggregate(wagehrfemadval,by=list(RHG),FUN=sum)
  SAMmatrix["flabfemadof ","aoffflmhi "] <- wagelabfemadagg$x[1] * incscalhlmhi
  SAMmatrix["flabfemadof ","aoffflmmd "] <- wagelabfemadagg$x[2] * incscalhlmmd
  SAMmatrix["flabfemadof ","aoffflmlo "] <- wagelabfemadagg$x[3] * incscalhlmlo
  SAMmatrix["flabfemadof ","aofffhmhi "] <- wagelabfemadagg$x[4] * incscalhhmhi
  SAMmatrix["flabfemadof ","aofffhmmd "] <- wagelabfemadagg$x[5] * incscalhhmmd
  SAMmatrix["flabfemadof ","aofffhmlo "] <- wagelabfemadagg$x[6] * incscalhhmlo
 wagelabfemecagg <- aggregate(wagehrfemeldval+wagehrfemchildval,by=list(RHG),FUN=sum)
  SAMmatrix["flabfemecof ","aoffflmhi "] <- wagelabfemecagg$x[1] * incscalhlmhi
  SAMmatrix["flabfemecof ","aoffflmmd "] <- wagelabfemecagg$x[2] * incscalhlmmd
  SAMmatrix["flabfemecof ","aoffflmlo "] <- wagelabfemecagg$x[3] * incscalhlmlo
  SAMmatrix["flabfemecof ","aofffhmhi "] <- wagelabfemecagg$x[4] * incscalhhmhi
  SAMmatrix["flabfemecof ","aofffhmmd "] <- wagelabfemecagg$x[5] * incscalhhmmd
  SAMmatrix["flabfemecof ","aofffhmlo "] <- wagelabfemecagg$x[6] * incscalhhmlo

offinflabmadagg <- aggregate(oddjhrmaladval+selfemphrmaladval,by=list(RHG),FUN=sum)
  SAMmatrix["flabmadoi ","aoffilmhi "] <- (offinflabmadagg$x[1]+500)  * incscalhlmhi 
  SAMmatrix["flabmadoi ","aoffilmmd "] <- (offinflabmadagg$x[2]-2000) * incscalhlmmd
  SAMmatrix["flabmadoi ","aoffilmlo "] <- (offinflabmadagg$x[3]-1840) * incscalhlmlo
  SAMmatrix["flabmadoi ","aoffihmhi "] <- offinflabmadagg$x[4]  * incscalhhmhi 
  SAMmatrix["flabmadoi ","aoffihmmd "] <- (offinflabmadagg$x[5]+100)  * incscalhhmmd 
  SAMmatrix["flabmadoi ","aoffihmlo "] <- offinflabmadagg$x[6]  * incscalhhmlo
offinflabmecagg <- aggregate(oddjhrmaleldval+selfemphrmalchildval,by=list(RHG),FUN=sum)
  SAMmatrix["flabmecoi ","aoffilmhi "] <- offinflabmecagg$x[1] * incscalhlmhi
  SAMmatrix["flabmecoi ","aoffilmmd "] <- offinflabmecagg$x[2] * incscalhlmmd 
  SAMmatrix["flabmecoi ","aoffilmlo "] <- offinflabmecagg$x[3] * incscalhlmlo 
  SAMmatrix["flabmecoi ","aoffihmhi "] <- offinflabmecagg$x[4] * incscalhhmhi
  SAMmatrix["flabmecoi ","aoffihmmd "] <- offinflabmecagg$x[5] * incscalhhmmd
  SAMmatrix["flabmecoi ","aoffihmlo "] <- offinflabmecagg$x[6] * incscalhhmlo
 offinflabfemadagg <- aggregate(oddjhrfemadval+selfemphrfemadval,by=list(RHG),FUN=sum)
  SAMmatrix["flabfemadoi ","aoffilmhi "] <- offinflabfemadagg$x[1] * incscalhlmhi 
  SAMmatrix["flabfemadoi ","aoffilmmd "] <- offinflabfemadagg$x[2] * incscalhlmmd 
  SAMmatrix["flabfemadoi ","aoffilmlo "] <- offinflabfemadagg$x[3] * incscalhlmlo 
  SAMmatrix["flabfemadoi ","aoffihmhi "] <- offinflabfemadagg$x[4] * incscalhhmhi 
  SAMmatrix["flabfemadoi ","aoffihmmd "] <- offinflabfemadagg$x[5] * incscalhhmmd 
  SAMmatrix["flabfemadoi ","aoffihmlo "] <- offinflabfemadagg$x[6] * incscalhhmlo 
 offinflabfemecagg <- aggregate(oddjhrfemeldval+selfemphrfemchildval,by=list(RHG),FUN=sum)
  SAMmatrix["flabfemecoi ","aoffilmhi "] <- offinflabfemecagg$x[1] * incscalhlmhi 
  SAMmatrix["flabfemecoi ","aoffilmmd "] <- offinflabfemecagg$x[2] * incscalhlmmd 
  SAMmatrix["flabfemecoi ","aoffilmlo "] <- offinflabfemecagg$x[3] * incscalhlmlo 
  SAMmatrix["flabfemecoi ","aoffihmhi "] <- offinflabfemecagg$x[4] * incscalhhmhi 
  SAMmatrix["flabfemecoi ","aoffihmmd "] <- offinflabfemecagg$x[5] * incscalhhmmd 
  SAMmatrix["flabfemecoi ","aoffihmlo "] <- offinflabfemecagg$x[6] * incscalhhmlo 

miglabmadagg <- aggregate(mighrmaladval,by=list(RHG),FUN=sum)
  SAMmatrix["flabmadm ","amiglmhi "] <- miglabmadagg$x[1] * incscalhlmhi
  SAMmatrix["flabmadm ","amiglmmd "] <- miglabmadagg$x[2] * incscalhlmmd
  SAMmatrix["flabmadm ","amiglmlo "] <- miglabmadagg$x[3] * incscalhlmlo
  SAMmatrix["flabmadm ","amighmhi "] <- miglabmadagg$x[4] * incscalhhmhi
  SAMmatrix["flabmadm ","amighmmd "] <- miglabmadagg$x[5] * incscalhhmmd
  SAMmatrix["flabmadm ","amighmlo "] <- miglabmadagg$x[6] * incscalhhmlo
 miglabmecagg <- aggregate(mighrmaleldval+migagrhrmalchildval,by=list(RHG),FUN=sum)
  SAMmatrix["flabmecm ","amiglmhi "] <- miglabmecagg$x[1] * incscalhlmhi
  SAMmatrix["flabmecm ","amiglmmd "] <- miglabmecagg$x[2] * incscalhlmmd
  SAMmatrix["flabmecm ","amiglmlo "] <- miglabmecagg$x[3] * incscalhlmlo
  SAMmatrix["flabmecm ","amighmhi "] <- miglabmecagg$x[4] * incscalhhmhi
  SAMmatrix["flabmecm ","amighmmd "] <- miglabmecagg$x[5] * incscalhhmmd
  SAMmatrix["flabmecm ","amighmlo "] <- miglabmecagg$x[6] * incscalhhmlo
 miglabfemadagg <- aggregate(mighrfemadval,by=list(RHG),FUN=sum)
  SAMmatrix["flabfemadm ","amiglmhi "] <- miglabfemadagg$x[1] * incscalhlmhi
  SAMmatrix["flabfemadm ","amiglmmd "] <- miglabfemadagg$x[2] * incscalhlmmd
  SAMmatrix["flabfemadm ","amiglmlo "] <- miglabfemadagg$x[3] * incscalhlmlo
  SAMmatrix["flabfemadm ","amighmhi "] <- miglabfemadagg$x[4] * incscalhhmhi
  SAMmatrix["flabfemadm ","amighmmd "] <- miglabfemadagg$x[5] * incscalhhmmd
  SAMmatrix["flabfemadm ","amighmlo "] <- miglabfemadagg$x[6] * incscalhhmlo
 miglabfemecagg <- aggregate(mighrfemeldval+mighrfemchildval,by=list(RHG),FUN=sum)
  SAMmatrix["flabfemecm ","amiglmhi "] <- miglabfemecagg$x[1] * incscalhlmhi
  SAMmatrix["flabfemecm ","amiglmmd "] <- miglabfemecagg$x[2] * incscalhlmmd
  SAMmatrix["flabfemecm ","amiglmlo "] <- miglabfemecagg$x[3] * incscalhlmlo
  SAMmatrix["flabfemecm ","amighmhi "] <- miglabfemecagg$x[4] * incscalhhmhi
  SAMmatrix["flabfemecm ","amighmmd "] <- miglabfemecagg$x[5] * incscalhhmmd
  SAMmatrix["flabfemecm ","amighmlo "] <- miglabfemecagg$x[6] * incscalhhmlo

## 18. HOUSEHOLD INCOME - Factor returns: Land

 totirrlandagr <- irrlandval + landprice*tianrentoutarea
 irrlandagragg <- aggregate(totirrlandagr,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flndirr "] <- irrlandagragg$x[1] *  flndirrscal * incscalhlmhi * flndirrscal2
 SAMmatrix["hlmmd ","flndirr "] <- irrlandagragg$x[2] *  flndirrscal * incscalhlmmd * flndirrscal2
 SAMmatrix["hlmlo ","flndirr "] <- irrlandagragg$x[3] *  flndirrscal * incscalhlmlo * flndirrscal2 
 SAMmatrix["hhmhi ","flndirr "] <- irrlandagragg$x[4] *  flndirrscal * incscalhhmhi * flndirrscal2
 SAMmatrix["hhmmd ","flndirr "] <- irrlandagragg$x[5] *  flndirrscal * incscalhhmmd * flndirrscal2
 SAMmatrix["hhmlo ","flndirr "] <- irrlandagragg$x[6] *  flndirrscal * incscalhhmlo * flndirrscal2

totnonirrlandagr <- nonirrlandval  + landprice*turentoutarea
 nonirrlandagragg <- aggregate(totnonirrlandagr,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","flndnirr "] <- nonirrlandagragg$x[1] *  flndnirrscal * incscalhlmhi * flndnirrscal2
 SAMmatrix["hlmmd ","flndnirr "] <- nonirrlandagragg$x[2] *  flndnirrscal * incscalhlmmd * flndnirrscal2
 SAMmatrix["hlmlo ","flndnirr "] <- nonirrlandagragg$x[3] *  flndnirrscal * incscalhlmlo * flndnirrscal2
 SAMmatrix["hhmhi ","flndnirr "] <- nonirrlandagragg$x[4] *  flndnirrscal * incscalhhmhi * flndnirrscal2
 SAMmatrix["hhmmd ","flndnirr "] <- nonirrlandagragg$x[5] *  flndnirrscal * incscalhhmmd * flndnirrscal2
 SAMmatrix["hhmlo ","flndnirr "] <- nonirrlandagragg$x[6] *  flndnirrscal * incscalhhmlo * flndnirrscal2

# SAM balancing: Add excess receipts of land factor accounts as payments to the migrated households. Further, assume that these payments to the migrated households flow out of the village.

 SAMmatrix["hhmig ","flndirr "] <- sum(landprice*tianrentinarea - landprice*tianrentoutarea ) * flndirrscal * flndirrscal2 + 2 
 SAMmatrix["hhmig ","flndnirr "] <- sum(landprice*turentinarea - landprice*turentoutarea ) * flndnirrscal * flndnirrscal2 - 3

 SAMmatrix["outvill ","hhmig "] <- sum(SAMmatrix["hhmig ",]) 

## 19. HOUSEHOLDS' OWN CONSUMPTION

 cagrselfagg <- aggregate(maizeself+rapeself+riceself+ograinself+ocrpcself + vegtself + fruitself +
                           porkself+beefself+poulself+eggself+olvskself+
                           fisheryhome+forestryhome+renthome+processhome+otherhome, by=list(RHG),FUN=sum)
 SAMmatrix["cagr ","hlmhi "] <- cagrselfagg$x[1] * agrselfscal
 SAMmatrix["cagr ","hlmmd "] <- cagrselfagg$x[2] * agrselfscal
 SAMmatrix["cagr ","hlmlo "] <- cagrselfagg$x[3] * agrselfscal
 SAMmatrix["cagr ","hhmhi "] <- cagrselfagg$x[4] * agrselfscal
 SAMmatrix["cagr ","hhmmd "] <- cagrselfagg$x[5] * agrselfscal
 SAMmatrix["cagr ","hhmlo "] <- cagrselfagg$x[6] * agrselfscal

## 20. HOUSEHOLD CONSUMPTION OF IMPORTED GOODS AND SERVICES

 totgrainyragg <- aggregate(totgrainyr, by=list(RHG),FUN=sum)
 SAMmatrix["cfdgrain ","hlmhi "] <- totgrainyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cfdgrain ","hlmmd "] <- totgrainyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cfdgrain ","hlmlo "] <- totgrainyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["cfdgrain ","hhmhi "] <- totgrainyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cfdgrain ","hhmmd "] <- totgrainyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["cfdgrain ","hhmlo "] <- totgrainyragg$x[6] * expscalhhmlo * expscalhhmlo2

 totvegfruityragg <- aggregate(totvegfruityr, by=list(RHG),FUN=sum)
 SAMmatrix["cfdffv ","hlmhi "] <- totvegfruityragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cfdffv ","hlmmd "] <- totvegfruityragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cfdffv ","hlmlo "] <- totvegfruityragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["cfdffv ","hhmhi "] <- totvegfruityragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cfdffv ","hhmmd "] <- totvegfruityragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["cfdffv ","hhmlo "] <- totvegfruityragg$x[6] * expscalhhmlo * expscalhhmlo2

 totprocyr <- toteatoutyr + totcondimentyr
 totprocyragg <- aggregate(totprocyr, by=list(RHG),FUN=sum)
 SAMmatrix["cfproc ","hlmhi "] <- totprocyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cfproc ","hlmmd "] <- totprocyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cfproc ","hlmlo "] <- totprocyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["cfproc ","hhmhi "] <- totprocyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cfproc ","hhmmd "] <- totprocyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["cfproc ","hhmlo "] <- totprocyragg$x[6] * expscalhhmlo * expscalhhmlo2

 totanimyr <- totmeateggyr + totseafooddairyyr
 totanimyragg <- aggregate(totanimyr, by=list(RHG),FUN=sum)
 SAMmatrix["cfanim ","hlmhi "] <- totanimyragg$x[1] * expscalhlmhi * expscalhlmhi2 + 607
 SAMmatrix["cfanim ","hlmmd "] <- totanimyragg$x[2] * expscalhlmmd * expscalhlmmd2 + 708
 SAMmatrix["cfanim ","hlmlo "] <- totanimyragg$x[3] * expscalhlmlo * expscalhlmlo2 
 SAMmatrix["cfanim ","hhmhi "] <- totanimyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cfanim ","hhmmd "] <- totanimyragg$x[5] * expscalhhmmd * expscalhhmmd2 - 835
 SAMmatrix["cfanim ","hhmlo "] <- totanimyragg$x[6] * expscalhhmlo * expscalhhmlo2 + 89

 totdurablesyr <- totdurablesyr + totclothingyr
 totdurablesyragg <- aggregate(totdurablesyr, by=list(RHG),FUN=sum)
 SAMmatrix["cnfdur ","hlmhi "] <- totdurablesyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cnfdur ","hlmmd "] <- totdurablesyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cnfdur ","hlmlo "] <- totdurablesyragg$x[3] * expscalhlmlo * expscalhlmlo2 - 406
 SAMmatrix["cnfdur ","hhmhi "] <- totdurablesyragg$x[4] * expscalhhmhi * expscalhhmhi2 - 163
 SAMmatrix["cnfdur ","hhmmd "] <- totdurablesyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["cnfdur ","hhmlo "] <- totdurablesyragg$x[6] * expscalhhmlo * expscalhhmlo2

 totdrinktabaccoyragg <- aggregate(totdrinktabaccoyr, by=list(RHG),FUN=sum)
 SAMmatrix["cnfstim ","hlmhi "] <- totdrinktabaccoyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cnfstim ","hlmmd "] <- totdrinktabaccoyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cnfstim ","hlmlo "] <- totdrinktabaccoyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["cnfstim ","hhmhi "] <- totdrinktabaccoyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cnfstim ","hhmmd "] <- totdrinktabaccoyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["cnfstim ","hhmlo "] <- totdrinktabaccoyragg$x[6] * expscalhhmlo * expscalhhmlo2

 tototheryr <- totdailymisyr + tototherexpyr
 tototheryragg <- aggregate(tototheryr, by=list(RHG),FUN=sum)
 SAMmatrix["coothr ","hlmhi "] <- tototheryragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["coothr ","hlmmd "] <- tototheryragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["coothr ","hlmlo "] <- tototheryragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["coothr ","hhmhi "] <- tototheryragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["coothr ","hhmmd "] <- tototheryragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["coothr ","hhmlo "] <- tototheryragg$x[6] * expscalhhmlo * expscalhhmlo2

 totwateryragg <- aggregate(totwateryr, by=list(RHG),FUN=sum)
 SAMmatrix["cswat ","hlmhi "] <- totwateryragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cswat ","hlmmd "] <- totwateryragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cswat ","hlmlo "] <- totwateryragg$x[3] * expscalhlmlo * expscalhlmlo2 
 SAMmatrix["cswat ","hhmhi "] <- totwateryragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cswat ","hhmmd "] <- totwateryragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["cswat ","hhmlo "] <- totwateryragg$x[6] * expscalhhmlo * expscalhhmlo2

 totenergyyr <- totcoalyr + totfuelyr + totelectricityyr
 totenergyyragg <- aggregate(totenergyyr, by=list(RHG),FUN=sum)
 SAMmatrix["csener ","hlmhi "] <- totenergyyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["csener ","hlmmd "] <- totenergyyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["csener ","hlmlo "] <- totenergyyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["csener ","hhmhi "] <- totenergyyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["csener ","hhmmd "] <- totenergyyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["csener ","hhmlo "] <- totenergyyragg$x[6] * expscalhhmlo * expscalhhmlo2

 tottransyr <- tottelephoneyr + tottransportyr
 tottransyragg <- aggregate(tottransyr, by=list(RHG),FUN=sum)
 SAMmatrix["cstrans ","hlmhi "] <- tottransyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cstrans ","hlmmd "] <- tottransyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cstrans ","hlmlo "] <- tottransyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["cstrans ","hhmhi "] <- tottransyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cstrans ","hhmmd "] <- tottransyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["cstrans ","hhmlo "] <- tottransyragg$x[6] * expscalhhmlo * expscalhhmlo2

 tothholdyragg <- aggregate(tothhexpyr, by=list(RHG),FUN=sum)
 SAMmatrix["cshhold ","hlmhi "] <- tothholdyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cshhold ","hlmmd "] <- tothholdyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cshhold ","hlmlo "] <- tothholdyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["cshhold ","hhmhi "] <- tothholdyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cshhold ","hhmmd "] <- tothholdyragg$x[5] * expscalhhmmd * expscalhhmmd2 
 SAMmatrix["cshhold ","hhmlo "] <- tothholdyragg$x[6] * expscalhhmlo * expscalhhmlo2

 tothlthyragg <- aggregate(totmedicineyr, by=list(RHG),FUN=sum)
 SAMmatrix["cshlth ","hlmhi "] <- tothlthyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["cshlth ","hlmmd "] <- tothlthyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["cshlth ","hlmlo "] <- tothlthyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["cshlth ","hhmhi "] <- tothlthyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["cshlth ","hhmmd "] <- tothlthyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["cshlth ","hhmlo "] <- tothlthyragg$x[6] * expscalhhmlo * expscalhhmlo2

 toteducationyragg <- aggregate(toteducationyr, by=list(RHG),FUN=sum)
 SAMmatrix["csedu ","hlmhi "] <- toteducationyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["csedu ","hlmmd "] <- toteducationyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["csedu ","hlmlo "] <- toteducationyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["csedu ","hhmhi "] <- toteducationyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["csedu ","hhmmd "] <- toteducationyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["csedu ","hhmlo "] <- toteducationyragg$x[6] * expscalhhmlo * expscalhhmlo2

## 7. IMPORTS CONSUMER GOODS & SERVICES

 SAMmatrix["outvill ","cfdgrain "]<- sum(SAMmatrix["cfdgrain ",]) + 1
 SAMmatrix["outvill ","cfdffv "]  <- sum(SAMmatrix["cfdffv ",]) 
 SAMmatrix["outvill ","cfproc "]  <- sum(SAMmatrix["cfproc ",]) 
 SAMmatrix["outvill ","cfanim "]  <- sum(SAMmatrix["cfanim ",]) + 1
 SAMmatrix["outvill ","cnfdur "]  <- sum(SAMmatrix["cnfdur ",]) - 1
 SAMmatrix["outvill ","cnfstim "] <- sum(SAMmatrix["cnfstim ",]) - 1
 SAMmatrix["outvill ","coothr "]  <- sum(SAMmatrix["coothr ",]) + 1
 SAMmatrix["outvill ","cswat "]   <- sum(SAMmatrix["cswat ",]) 
 SAMmatrix["outvill ","csener "]  <- sum(SAMmatrix["csener ",]) - 2
 SAMmatrix["outvill ","cstrans "] <- sum(SAMmatrix["cstrans ",]) 
 SAMmatrix["outvill ","cshhold "] <- sum(SAMmatrix["cshhold ",]) + 1
 SAMmatrix["outvill ","cshlth "]  <- sum(SAMmatrix["cshlth ",]) - 1
 SAMmatrix["outvill ","csedu "]   <- sum(SAMmatrix["csedu ",]) 

## 21. HOUSEHOLD CONSUMPTION OF LEISURE

 maladleisagg <- aggregate(leishrmaladval, by=list(RHG),FUN=sum)
 SAMmatrix["flabmadl ","hlmhi "] <- maladleisagg$x[1]
 SAMmatrix["flabmadl ","hlmmd "] <- maladleisagg$x[2]
 SAMmatrix["flabmadl ","hlmlo "] <- maladleisagg$x[3]
 SAMmatrix["flabmadl ","hhmhi "] <- maladleisagg$x[4]
 SAMmatrix["flabmadl ","hhmmd "] <- maladleisagg$x[5]
 SAMmatrix["flabmadl ","hhmlo "] <- maladleisagg$x[6]

 malecleisagg <- aggregate(leishrmaleldval+leishrmalchildval, by=list(RHG),FUN=sum)
 SAMmatrix["flabmecl ","hlmhi "] <- malecleisagg$x[1] 
 SAMmatrix["flabmecl ","hlmmd "] <- malecleisagg$x[2]
 SAMmatrix["flabmecl ","hlmlo "] <- malecleisagg$x[3]
 SAMmatrix["flabmecl ","hhmhi "] <- malecleisagg$x[4]
 SAMmatrix["flabmecl ","hhmmd "] <- malecleisagg$x[5]
 SAMmatrix["flabmecl ","hhmlo "] <- malecleisagg$x[6]

 femadleisagg <- aggregate(leishrfemadval, by=list(RHG),FUN=sum)
 SAMmatrix["flabfemadl ","hlmhi "] <- femadleisagg$x[1]
 SAMmatrix["flabfemadl ","hlmmd "] <- femadleisagg$x[2]
 SAMmatrix["flabfemadl ","hlmlo "] <- femadleisagg$x[3]
 SAMmatrix["flabfemadl ","hhmhi "] <- femadleisagg$x[4]
 SAMmatrix["flabfemadl ","hhmmd "] <- femadleisagg$x[5]
 SAMmatrix["flabfemadl ","hhmlo "] <- femadleisagg$x[6]

 femecleisagg <- aggregate(leishrfemeldval+leishrfemchildval, by=list(RHG),FUN=sum)
 SAMmatrix["flabfemecl ","hlmhi "] <- femecleisagg$x[1]
 SAMmatrix["flabfemecl ","hlmmd "] <- femecleisagg$x[2]
 SAMmatrix["flabfemecl ","hlmlo "] <- femecleisagg$x[3]
 SAMmatrix["flabfemecl ","hhmhi "] <- femecleisagg$x[4]
 SAMmatrix["flabfemecl ","hhmmd "] <- femecleisagg$x[5]
 SAMmatrix["flabfemecl ","hhmlo "] <- femecleisagg$x[6]

## 22. HOUSEHOLD EXPENDITURE ON GIFTS, TRANSFERS, ETC.

 tottrgiftyragg <- aggregate(totgiftyr, by=list(RHG),FUN=sum)
 SAMmatrix["trgift ","hlmhi "] <- tottrgiftyragg$x[1] 
 SAMmatrix["trgift ","hlmmd "] <- tottrgiftyragg$x[2] 
 SAMmatrix["trgift ","hlmlo "] <- tottrgiftyragg$x[3] 
 SAMmatrix["trgift ","hhmhi "] <- tottrgiftyragg$x[4] 
 SAMmatrix["trgift ","hhmmd "] <- tottrgiftyragg$x[5] 
 SAMmatrix["trgift ","hhmlo "] <- tottrgiftyragg$x[6] 

 tottrbigaffairsyragg <- aggregate(totbigaffairsyr, by=list(RHG),FUN=sum)
 SAMmatrix["trshock ","hlmhi "] <- tottrbigaffairsyragg$x[1] * expscalhlmhi
 SAMmatrix["trshock ","hlmmd "] <- tottrbigaffairsyragg$x[2] * expscalhlmmd
 SAMmatrix["trshock ","hlmlo "] <- tottrbigaffairsyragg$x[3] * expscalhlmlo
 SAMmatrix["trshock ","hhmhi "] <- tottrbigaffairsyragg$x[4] * expscalhhmhi
 SAMmatrix["trshock ","hhmmd "] <- tottrbigaffairsyragg$x[5] * expscalhhmmd 
 SAMmatrix["trshock ","hhmlo "] <- tottrbigaffairsyragg$x[6] * expscalhhmlo 

## 23. HOUSEHOLD SAVINGS

 totsiconsyragg <- aggregate(tothouseyr, by=list(RHG),FUN=sum)
 SAMmatrix["sicons ","hlmhi "] <- totsiconsyragg$x[1] * expscalhlmhi * expscalhlmhi2
 SAMmatrix["sicons ","hlmmd "] <- totsiconsyragg$x[2] * expscalhlmmd * expscalhlmmd2
 SAMmatrix["sicons ","hlmlo "] <- totsiconsyragg$x[3] * expscalhlmlo * expscalhlmlo2
 SAMmatrix["sicons ","hhmhi "] <- totsiconsyragg$x[4] * expscalhhmhi * expscalhhmhi2
 SAMmatrix["sicons ","hhmmd "] <- totsiconsyragg$x[5] * expscalhhmmd * expscalhhmmd2
 SAMmatrix["sicons ","hhmlo "] <- totsiconsyragg$x[6] * expscalhhmlo * expscalhhmlo2

# SAM balancing: Assume that all expenditures on construction flow directly out of the village
 SAMmatrix["outvill ","sicons "] <- sum(SAMmatrix["sicons ",]) 

 totsisiyragg <- aggregate(totinterestyr, by=list(RHG),FUN=sum)
 SAMmatrix["sisi ","hlmhi "] <- totsisiyragg$x[1] * expscalhlmhi - 1
 SAMmatrix["sisi ","hlmmd "] <- totsisiyragg$x[2] * expscalhlmmd - 1
 SAMmatrix["sisi ","hlmlo "] <- totsisiyragg$x[3] * expscalhlmlo - 2
 SAMmatrix["sisi ","hhmhi "] <- totsisiyragg$x[4] * expscalhhmhi
 SAMmatrix["sisi ","hhmmd "] <- totsisiyragg$x[5] * expscalhhmmd
 SAMmatrix["sisi ","hhmlo "] <- totsisiyragg$x[6] * expscalhhmlo

## 24. HOUSEHOLD INCOME FROM TRANSFERS, GIFTS, etc.

 tottrgiftinc <- gift + transferlocal 
 trgiftincagg <- aggregate(tottrgiftinc,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","trgift "] <- trgiftincagg$x[1] * trgiftscal
 SAMmatrix["hlmmd ","trgift "] <- trgiftincagg$x[2] * trgiftscal
 SAMmatrix["hlmlo ","trgift "] <- trgiftincagg$x[3] * trgiftscal
 SAMmatrix["hhmhi ","trgift "] <- trgiftincagg$x[4] * trgiftscal 
 SAMmatrix["hhmmd ","trgift "] <- trgiftincagg$x[5] * trgiftscal 
 SAMmatrix["hhmlo ","trgift "] <- trgiftincagg$x[6] * trgiftscal 

 trshockincagg <- aggregate(ss,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","trshock "] <- trshockincagg$x[1]
 SAMmatrix["hlmmd ","trshock "] <- trshockincagg$x[2]
 SAMmatrix["hlmlo ","trshock "] <- trshockincagg$x[3]
 SAMmatrix["hhmhi ","trshock "] <- trshockincagg$x[4]
 SAMmatrix["hhmmd ","trshock "] <- trshockincagg$x[5]
 SAMmatrix["hhmlo ","trshock "] <- trshockincagg$x[6] 

# 25. HOUSEHOLD INCOME FROM SAVINGS (Interest payments)

# Some comments on the sisi account: The sisi account contains household income and expenditure from and on interest. As in the survey data, no household reports income from interest, all payments are assumed to flow out of the village. In addition, the sisi account includes savings and dissavings (payment flows from a capital stocks). Household data on savings is not available, hence, it is assumed that savings takes place only in form of house construction and - as savings in a broader sense - through the purchase of durable goods. Regarding dissavings, no detailed data is available, either. However, 86.17% of the households in Changtian state some sort of dissaving (self-deposit savings, sales of family property, loans) as the major source for big expenditures. Hence, in a very simplifying manner it is assumed that 85% of household expenditures on items which comprise"big expenditures" (construction, shocks and health) are covered by payments from the sisi account. Finally, the sisi account is balanced through a negative payment to outside the village which corresponds to the difference between the payments received by the sisi account and its expenses. This assumption can be maintained as households in order to cover big expenditures either sell assets or take loans. The latter can safely be assumed to originate from outside the village while assets can be sold to outside the village.    

 trinterestincagg <- aggregate(interest,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","sisi "] <- trinterestincagg$x[1]+(SAMmatrix["sicons ","hlmhi "]+SAMmatrix["trshock ","hlmhi "]+SAMmatrix["cshlth ","hlmhi "]) * 0.85 
 SAMmatrix["hlmmd ","sisi "] <- trinterestincagg$x[2]+(SAMmatrix["sicons ","hlmmd "]+SAMmatrix["trshock ","hlmmd "]+SAMmatrix["cshlth ","hlmmd "])* 0.85  
 SAMmatrix["hlmlo ","sisi "] <- trinterestincagg$x[3]+(SAMmatrix["sicons ","hlmlo "]+SAMmatrix["trshock ","hlmlo "]+SAMmatrix["cshlth ","hlmlo "])* 0.85   
 SAMmatrix["hhmhi ","sisi "] <- trinterestincagg$x[4]+(SAMmatrix["sicons ","hhmhi "]+SAMmatrix["trshock ","hhmhi "]+SAMmatrix["cshlth ","hhmhi "])* 0.85   
 SAMmatrix["hhmmd ","sisi "] <- trinterestincagg$x[5]+(SAMmatrix["sicons ","hhmmd "]+SAMmatrix["trshock ","hhmmd "]+SAMmatrix["cshlth ","hlmmd "])* 0.85   
 SAMmatrix["hhmlo ","sisi "] <- trinterestincagg$x[6]+(SAMmatrix["sicons ","hhmlo "]+SAMmatrix["trshock ","hhmlo "]+SAMmatrix["cshlth ","hhmlo "])* 0.85

 SAMmatrix["outvill ","sisi "] <- sum(SAMmatrix["sisi ",]) - sum(SAMmatrix[,"sisi "]) + 1

# SAM balancing: Receipts of the transfer accounts from households are higher than payments from the accounts to households assume that the village is a net payer of transfers to the outside world and introduce payments from the transfer accounts to outvill. This makes sense, as most of the"big affairs" which are included here involve purchases from outside the village.

 SAMmatrix["outvill ","trshock "] <-  sum(SAMmatrix["trshock ",]) - sum(SAMmatrix[,"trshock "]) - 1

# 26. GOVERNMENT TRANSFERS TO HOUSEHOLDS

 govtrans <- food + disaster.x + subsidy + transfer # Note that transfer actually do not come from the government, but for matters of convenience are included here 
 trgovincagg <- aggregate(govtrans,by=list(RHG),FUN=sum)
 SAMmatrix["hlmhi ","gov "] <- trgovincagg$x[1] * incscalhlmhi
 SAMmatrix["hlmmd ","gov "] <- trgovincagg$x[2] * incscalhlmmd
 SAMmatrix["hlmlo ","gov "] <- trgovincagg$x[3] * incscalhlmlo
 SAMmatrix["hhmhi ","gov "] <- trgovincagg$x[4] * incscalhhmhi
 SAMmatrix["hhmmd ","gov "] <- trgovincagg$x[5] * incscalhhmmd
 SAMmatrix["hhmlo ","gov "] <- trgovincagg$x[6] * incscalhhmlo
# SAM balancing: As there are no taxes paid nor are there other transfer from the village to the government, the account is balanced by a negative payment to outvill.

 SAMmatrix["outvill ","gov "] = -sum(SAMmatrix[,"gov "]) 

# 27. VILLAGE EXPORTS (all sales)

 SAMmatrix["cagr ","outvill "] <- sum(cornsale+maizesale+rapesale+oilsale+ricesale+paddysale+ograinsale+ocropsale+
                                       vegsale+fruitsale+
                                       pigsale+cowsale+poultrysale+eggsale+oanimalsale+
                                       fisherysale + forestrysale + rentsale + processsale + othersale) * cagrecscal

# 28. PAYMENTS TO BLOOD ACTIVITY

 SAMmatrix["abloodlmhi ","outvill "] <- SAMmatrix["hlmhi ","abloodlmhi "]
 SAMmatrix["abloodlmmd ","outvill "] <- SAMmatrix["hlmmd ","abloodlmmd "]
 SAMmatrix["abloodlmlo ","outvill "] <- SAMmatrix["hlmlo ","abloodlmlo "]
 SAMmatrix["abloodhmhi ","outvill "] <- SAMmatrix["hhmhi ","abloodhmhi "]
 SAMmatrix["abloodhmmd ","outvill "] <- SAMmatrix["hhmmd ","abloodhmmd "]
 SAMmatrix["abloodhmlo ","outvill "] <- SAMmatrix["hhmlo ","abloodhmlo "]  

## 31. PROFITS

# SAM balancing: Change the way profits are calculated and introduce scaling factors. This involves three steps
# 1. For each activity and each household scale total returns from participation in the activity by multiplication with the scaling factors.
# 2. For each activity and labor type substract the implicit labor cost as calculated under"16profits. HOUSEHOLD INCOME - Factor returns: Nonagricultural labor - profit version" to obtain the profits.
# 3. Aggregate these for all labor types to obtain the respective SAM entries.

## Local off-farm
 wageincmaladagg <- aggregate(wageincmaladhh,by=list(RHG),FUN=sum)
 hlmhiwageincmalad <- wageincmaladagg$x[1] * incscalhlmhi
 hlmmdwageincmalad <- wageincmaladagg$x[2] * incscalhlmmd
 hlmlowageincmalad <- wageincmaladagg$x[3] * incscalhlmlo
 hhmhiwageincmalad <- wageincmaladagg$x[4] * incscalhhmhi
 hhmmdwageincmalad <- wageincmaladagg$x[5] * incscalhhmmd
 hhmlowageincmalad <- wageincmaladagg$x[6] * incscalhhmlo

 wageincmalecagg <- aggregate(wageincmaleldhh+wageincmalchildhh,by=list(RHG),FUN=sum)
 hlmhiwageincmalec <- wageincmalecagg$x[1] * incscalhlmhi
 hlmmdwageincmalec <- wageincmalecagg$x[2] * incscalhlmmd
 hlmlowageincmalec <- wageincmalecagg$x[3] * incscalhlmlo
 hhmhiwageincmalec <- wageincmalecagg$x[4] * incscalhhmhi
 hhmmdwageincmalec <- wageincmalecagg$x[5] * incscalhhmmd
 hhmlowageincmalec <- wageincmalecagg$x[6] * incscalhhmlo

 wageincfemadagg <- aggregate(wageincfemadhh,by=list(RHG),FUN=sum)
 hlmhiwageincfemad <- wageincfemadagg$x[1] * incscalhlmhi
 hlmmdwageincfemad <- wageincfemadagg$x[2] * incscalhlmmd
 hlmlowageincfemad <- wageincfemadagg$x[3] * incscalhlmlo
 hhmhiwageincfemad <- wageincfemadagg$x[4] * incscalhhmhi
 hhmmdwageincfemad <- wageincfemadagg$x[5] * incscalhhmmd
 hhmlowageincfemad <- wageincfemadagg$x[6] * incscalhhmlo

 wageincfemecagg <- aggregate(wageincfemeldhh+wageincfemchildhh,by=list(RHG),FUN=sum)
 hlmhiwageincfemec <- wageincfemecagg$x[1] * incscalhlmhi
 hlmmdwageincfemec <- wageincfemecagg$x[2] * incscalhlmmd
 hlmlowageincfemec <- wageincfemecagg$x[3] * incscalhlmlo
 hhmhiwageincfemec <- wageincfemecagg$x[4] * incscalhhmhi
 hhmmdwageincfemec <- wageincfemecagg$x[5] * incscalhhmmd
 hhmlowageincfemec <- wageincfemecagg$x[6] * incscalhhmlo

 SAMmatrix["hlmhi ","aoffflmhi "] <- hlmhiwageincmalad+hlmhiwageincmalec+hlmhiwageincfemad+hlmhiwageincfemec-SAMmatrix["hlmhi ","flabmadof "]-SAMmatrix["hlmhi ","flabmecof "]-SAMmatrix["hlmhi ","flabfemadof "]-SAMmatrix["hlmhi ","flabfemecof "]    
 SAMmatrix["hlmmd ","aoffflmmd "] <- hlmmdwageincmalad+hlmmdwageincmalec+hlmmdwageincfemad+hlmmdwageincfemec-SAMmatrix["hlmmd ","flabmadof "]-SAMmatrix["hlmmd ","flabmecof "]-SAMmatrix["hlmmd ","flabfemadof "]-SAMmatrix["hlmmd ","flabfemecof "]
 SAMmatrix["hlmlo ","aoffflmlo "] <- hlmlowageincmalad+hlmlowageincmalec+hlmlowageincfemad+hlmlowageincfemec-SAMmatrix["hlmlo ","flabmadof "]-SAMmatrix["hlmlo ","flabmecof "]-SAMmatrix["hlmlo ","flabfemadof "]-SAMmatrix["hlmlo ","flabfemecof "]
 SAMmatrix["hhmhi ","aofffhmhi "] <- hhmhiwageincmalad+hhmhiwageincmalec+hhmhiwageincfemad+hhmhiwageincfemec-SAMmatrix["hhmhi ","flabmadof "]-SAMmatrix["hhmhi ","flabmecof "]-SAMmatrix["hhmhi ","flabfemadof "]-SAMmatrix["hhmhi ","flabfemecof "]   
 SAMmatrix["hhmmd ","aofffhmmd "] <- hhmmdwageincmalad+hhmmdwageincmalec+hhmmdwageincfemad+hhmmdwageincfemec-SAMmatrix["hhmmd ","flabmadof "]-SAMmatrix["hhmmd ","flabmecof "]-SAMmatrix["hhmmd ","flabfemadof "]-SAMmatrix["hhmmd ","flabfemecof "]
 SAMmatrix["hhmlo ","aofffhmlo "] <- hhmlowageincmalad+hhmlowageincmalec+hhmlowageincfemad+hhmlowageincfemec-SAMmatrix["hhmlo ","flabmadof "]-SAMmatrix["hhmlo ","flabmecof "]-SAMmatrix["hhmlo ","flabfemadof "]-SAMmatrix["hhmlo ","flabfemecof "] 

## Local informal off-farm employment

# a) Total returns per household group
 offinfmaladagg <- aggregate(oddincmaladhh+selfincmaladhh,by=list(RHG),FUN=sum)
 hlmhioffinfmalad <- offinfmaladagg$x[1] * incscalhlmhi 
 hlmmdoffinfmalad <- offinfmaladagg$x[2] * incscalhlmmd
 hlmlooffinfmalad <- offinfmaladagg$x[3] * incscalhlmlo
 hhmhioffinfmalad <- offinfmaladagg$x[4] * incscalhhmhi
 hhmmdoffinfmalad <- offinfmaladagg$x[5] * incscalhhmmd
 hhmlooffinfmalad <- offinfmaladagg$x[6] * incscalhhmlo

 offinfmalecagg <- aggregate(oddincmaleldhh+oddincmalchildhh+selfincmaleldhh+selfincmalchildhh,by=list(RHG),FUN=sum)
 hlmhioffinfmalec <- offinfmalecagg$x[1] * incscalhlmhi  
 hlmmdoffinfmalec <- offinfmalecagg$x[2] * incscalhlmmd
 hlmlooffinfmalec <- offinfmalecagg$x[3] * incscalhlmlo
 hhmhioffinfmalec <- offinfmalecagg$x[4] * incscalhhmhi
 hhmmdoffinfmalec <- offinfmalecagg$x[5] * incscalhhmmd
 hhmlooffinfmalec <- offinfmalecagg$x[6] * incscalhhmlo

 offinffemadagg <- aggregate(oddincfemadhh+selfincfemadhh,by=list(RHG),FUN=sum)
 hlmhioffinffemad <- offinffemadagg$x[1] * incscalhlmhi 
 hlmmdoffinffemad <- offinffemadagg$x[2] * incscalhlmmd
 hlmlooffinffemad <- offinffemadagg$x[3] * incscalhlmlo
 hhmhioffinffemad <- offinffemadagg$x[4] * incscalhhmhi
 hhmmdoffinffemad <- offinffemadagg$x[5] * incscalhhmmd
 hhmlooffinffemad <- offinffemadagg$x[6] * incscalhhmlo

 offinffemecagg <- aggregate(oddincfemeldhh+oddincfemchildhh+selfincfemeldhh+selfincfemchildhh,by=list(RHG),FUN=sum)
 hlmhioffinffemec <- offinffemecagg$x[1] * incscalhlmhi 
 hlmmdoffinffemec <- offinffemecagg$x[2] * incscalhlmmd
 hlmlooffinffemec <- offinffemecagg$x[3] * incscalhlmlo
 hhmhioffinffemec <- offinffemecagg$x[4] * incscalhhmhi
 hhmmdoffinffemec <- offinffemecagg$x[5] * incscalhhmmd
 hhmlooffinffemec <- offinffemecagg$x[6] * incscalhhmlo

# b) Total labor cost per household group
 offinfmaladcagg <- aggregate(oddjhrmaladval,by=list(RHG),FUN=sum)
 hlmhioffinfmaladc <- offinfmaladcagg$x[1] * incscalhlmhi 
 hlmmdoffinfmaladc <- offinfmaladcagg$x[2] * incscalhlmmd
 hlmlooffinfmaladc <- offinfmaladcagg$x[3] * incscalhlmlo
 hhmhioffinfmaladc <- offinfmaladcagg$x[4] * incscalhhmhi
 hhmmdoffinfmaladc <- offinfmaladcagg$x[5] * incscalhhmmd
 hhmlooffinfmaladc <- offinfmaladcagg$x[6] * incscalhhmlo

 offinfmaleccagg <- aggregate(oddjhrmaleldval+oddjhrmalchildval+selfemphrmaleldval+selfemphrmalchildval,by=list(RHG),FUN=sum)
 hlmhioffinfmalecc <- offinfmaleccagg$x[1] * incscalhlmhi 
 hlmmdoffinfmalecc <- offinfmaleccagg$x[2] * incscalhlmmd
 hlmlooffinfmalecc <- offinfmaleccagg$x[3] * incscalhlmlo
 hhmhioffinfmalecc <- offinfmaleccagg$x[4] * incscalhhmhi
 hhmmdoffinfmalecc <- offinfmaleccagg$x[5] * incscalhhmmd 
 hhmlooffinfmalecc <- offinfmaleccagg$x[6] * incscalhhmlo

 offinffemadcagg <- aggregate(oddjhrfemadval+selfemphrfemadval,by=list(RHG),FUN=sum)
 hlmhioffinffemadc <- offinffemadcagg$x[1] * incscalhlmhi 
 hlmmdoffinffemadc <- offinffemadcagg$x[2] * incscalhlmmd
 hlmlooffinffemadc <- offinffemadcagg$x[3] * incscalhlmlo
 hhmhioffinffemadc <- offinffemadcagg$x[4] * incscalhhmhi
 hhmmdoffinffemadc <- offinffemadcagg$x[5] * incscalhhmmd
 hhmlooffinffemadc <- offinffemadcagg$x[6] * incscalhhmlo

 offinffemeccagg <- aggregate(oddjhrfemeldval+oddjhrfemchildval+selfemphrfemeldval+selfemphrfemchildval,by=list(RHG),FUN=sum)
 hlmhioffinffemecc <- offinffemeccagg$x[1] * incscalhlmhi 
 hlmmdoffinffemecc <- offinffemeccagg$x[2] * incscalhlmmd
 hlmlooffinffemecc <- offinffemeccagg$x[3] * incscalhlmlo
 hhmhioffinffemecc <- offinffemeccagg$x[4] * incscalhhmhi
 hhmmdoffinffemecc <- offinffemeccagg$x[5] * incscalhhmmd
 hhmlooffinffemecc <- offinffemeccagg$x[6] * incscalhhmlo
 
 SAMmatrix["hlmhi ","aoffilmhi "] <-((hlmhioffinfmalad+hlmhioffinfmalec+hlmhioffinffemad+hlmhioffinffemec-(hlmhioffinfmaladc+hlmhioffinfmalecc+hlmhioffinffemadc+hlmhioffinffemecc)))
 SAMmatrix["hlmmd ","aoffilmmd "] <- (hlmmdoffinfmalad+hlmmdoffinfmalec+hlmmdoffinffemad+hlmmdoffinffemec-(hlmmdoffinfmaladc+hlmmdoffinfmalecc+hlmmdoffinffemadc+hlmmdoffinffemecc))
 SAMmatrix["hlmlo ","aoffilmlo "] <- (hlmlooffinfmalad+hlmlooffinfmalec+hlmlooffinffemad+hlmlooffinffemec-(hlmlooffinfmaladc+hlmlooffinfmalecc+hlmlooffinffemadc+hlmlooffinffemecc)) 
 SAMmatrix["hhmhi ","aoffihmhi "] <- (hhmhioffinfmalad+hhmhioffinfmalec+hhmhioffinffemad+hhmhioffinffemec-(hhmhioffinfmaladc+hhmhioffinfmalecc+hhmhioffinffemadc+hhmhioffinffemecc)) 
 SAMmatrix["hhmmd ","aoffihmmd "] <- (hhmmdoffinfmalad+hhmmdoffinfmalec+hhmmdoffinffemad+hhmmdoffinffemec-(hhmmdoffinfmaladc+hhmmdoffinfmalecc+hhmmdoffinffemadc+hhmmdoffinffemecc)) 
 SAMmatrix["hhmlo ","aoffihmlo "] <- (hhmlooffinfmalad+hhmlooffinfmalec+hhmlooffinffemad+hhmlooffinffemec-(hhmlooffinfmaladc+hhmlooffinfmalecc+hhmlooffinffemadc+hhmlooffinffemecc)) 

## Migration
# a) Total returns per household group
 migmaladagg <- aggregate(remitmaladhh,by=list(RHG),FUN=sum)
 hlmhimigmalad <- migmaladagg$x[1] * incscalhlmhi
 hlmmdmigmalad <- migmaladagg$x[2] * incscalhlmmd
 hlmlomigmalad <- migmaladagg$x[3] * incscalhlmlo
 hhmhimigmalad <- migmaladagg$x[4] * incscalhhmhi
 hhmmdmigmalad <- migmaladagg$x[5] * incscalhhmmd
 hhmlomigmalad <- migmaladagg$x[6] * incscalhhmlo

 migmalecagg <- aggregate(remitmaleldhh+remitmalchildhh,by=list(RHG),FUN=sum)
 hlmhimigmalec <- migmalecagg$x[1] * incscalhlmhi
 hlmmdmigmalec <- migmalecagg$x[2] * incscalhlmmd
 hlmlomigmalec <- migmalecagg$x[3] * incscalhlmlo
 hhmhimigmalec <- migmalecagg$x[4] * incscalhhmhi
 hhmmdmigmalec <- migmalecagg$x[5] * incscalhhmmd
 hhmlomigmalec <- migmalecagg$x[6] * incscalhhmlo

 migfemadagg <- aggregate(remitfemadhh,by=list(RHG),FUN=sum)
 hlmhimigfemad <- migfemadagg$x[1] * incscalhlmhi
 hlmmdmigfemad <- migfemadagg$x[2] * incscalhlmmd
 hlmlomigfemad <- migfemadagg$x[3] * incscalhlmlo
 hhmhimigfemad <- migfemadagg$x[4] * incscalhhmhi
 hhmmdmigfemad <- migfemadagg$x[5] * incscalhhmmd
 hhmlomigfemad <- migfemadagg$x[6] * incscalhhmlo

 migfemecagg <- aggregate(remitfemeldhh+remitfemchildhh,by=list(RHG),FUN=sum)
 hlmhimigfemec <- migfemecagg$x[1] * incscalhlmhi
 hlmmdmigfemec <- migfemecagg$x[2] * incscalhlmmd
 hlmlomigfemec <- migfemecagg$x[3] * incscalhlmlo
 hhmhimigfemec <- migfemecagg$x[4] * incscalhhmhi
 hhmmdmigfemec <- migfemecagg$x[5] * incscalhhmmd
 hhmlomigfemec <- migfemecagg$x[6] * incscalhhmlo

# b) Total labor cost per household group
 migmaladcagg <- aggregate(mighrmaladval,by=list(RHG),FUN=sum)
 hlmhimigmaladc <- migmaladcagg$x[1] * incscalhlmhi
 hlmmdmigmaladc <- migmaladcagg$x[2] * incscalhlmmd
 hlmlomigmaladc <- migmaladcagg$x[3] * incscalhlmlo
 hhmhimigmaladc <- migmaladcagg$x[4] * incscalhhmhi
 hhmmdmigmaladc <- migmaladcagg$x[5] * incscalhhmmd
 hhmlomigmaladc <- migmaladcagg$x[6] * incscalhhmlo

 migmaleccagg <- aggregate(mighrmaleldval+mighrmalchildval,by=list(RHG),FUN=sum)
 hlmhimigmalecc <- migmaleccagg$x[1] * incscalhlmhi
 hlmmdmigmalecc <- migmaleccagg$x[2] * incscalhlmmd
 hlmlomigmalecc <- migmaleccagg$x[3] * incscalhlmlo
 hhmhimigmalecc <- migmaleccagg$x[4] * incscalhhmhi
 hhmmdmigmalecc <- migmaleccagg$x[5] * incscalhhmmd
 hhmlomigmalecc <- migmaleccagg$x[6] * incscalhhmlo

 migfemadcagg <- aggregate(mighrfemadval,by=list(RHG),FUN=sum)
 hlmhimigfemadc <- migfemadcagg$x[1] * incscalhlmhi
 hlmmdmigfemadc <- migfemadcagg$x[2] * incscalhlmmd
 hlmlomigfemadc <- migfemadcagg$x[3] * incscalhlmlo
 hhmhimigfemadc <- migfemadcagg$x[4] * incscalhhmhi
 hhmmdmigfemadc <- migfemadcagg$x[5] * incscalhhmmd
 hhmlomigfemadc <- migfemadcagg$x[6] * incscalhhmlo

 migfemeccagg <- aggregate(mighrfemeldval+mighrfemchildval,by=list(RHG),FUN=sum)
 hlmhimigfemecc <- migfemeccagg$x[1] * incscalhlmhi
 hlmmdmigfemecc <- migfemeccagg$x[2] * incscalhlmmd
 hlmlomigfemecc <- migfemeccagg$x[3] * incscalhlmlo
 hhmhimigfemecc <- migfemeccagg$x[4] * incscalhhmhi
 hhmmdmigfemecc <- migfemeccagg$x[5] * incscalhhmmd
 hhmlomigfemecc <- migfemeccagg$x[6] * incscalhhmlo

 SAMmatrix["hlmhi ","amiglmhi "] <- hlmhimigmalad+hlmhimigmalec+hlmhimigfemad+hlmhimigfemec-(hlmhimigmaladc+hlmhimigmalecc+hlmhimigfemadc+hlmhimigfemecc)
 SAMmatrix["hlmmd ","amiglmmd "] <- hlmmdmigmalad+hlmmdmigmalec+hlmmdmigfemad+hlmmdmigfemec-(hlmmdmigmaladc+hlmmdmigmalecc+hlmmdmigfemadc+hlmmdmigfemecc)
 SAMmatrix["hlmlo ","amiglmlo "] <- hlmlomigmalad+hlmlomigmalec+hlmlomigfemad+hlmlomigfemec-(hlmlomigmaladc+hlmlomigmalecc+hlmlomigfemadc+hlmlomigfemecc)
 SAMmatrix["hhmhi ","amighmhi "] <- hhmhimigmalad+hhmhimigmalec+hhmhimigfemad+hhmhimigfemec-(hhmhimigmaladc+hhmhimigmalecc+hhmhimigfemadc+hhmhimigfemecc)
 SAMmatrix["hhmmd ","amighmmd "] <- hhmmdmigmalad+hhmmdmigmalec+hhmmdmigfemad+hhmmdmigfemec-(hhmmdmigmaladc+hhmmdmigmalecc+hhmmdmigfemadc+hhmmdmigfemecc)
 SAMmatrix["hhmlo ","amighmlo "] <- hhmlomigmalad+hhmlomigmalec+hhmlomigfemad+hhmlomigfemec-(hhmlomigmaladc+hhmlomigmalecc+hhmlomigfemadc+hhmlomigfemecc)

## 5. INCOME FROM AGRICULTURAL OFF-FARM EMPLOYMENT INSIDE VILLAGE

 SAMmatrix["aoffilmhi ","clabagvil "] <- SAMmatrix["clabagvil ","aagrlmhi "] 
 SAMmatrix["aoffilmmd ","clabagvil "] <- SAMmatrix["clabagvil ","aagrlmmd "]
 SAMmatrix["aoffilmlo ","clabagvil "] <- SAMmatrix["clabagvil ","aagrlmlo "]
 SAMmatrix["aoffihmhi ","clabagvil "] <- SAMmatrix["clabagvil ","aagrhmhi "]
 SAMmatrix["aoffihmmd ","clabagvil "] <- SAMmatrix["clabagvil ","aagrhmmd "]
 SAMmatrix["aoffihmlo ","clabagvil "] <- SAMmatrix["clabagvil ","aagrhmlo "]

# 29. RETURNS FROM OFF-FARM EMPLOYMENT

 SAMmatrix["aoffflmhi ","outvill "] <- sum(SAMmatrix[,"aoffflmhi "]) + 1
 SAMmatrix["aoffflmmd ","outvill "] <- sum(SAMmatrix[,"aoffflmmd "])
 SAMmatrix["aoffflmlo ","outvill "] <- sum(SAMmatrix[,"aoffflmlo "])
 SAMmatrix["aofffhmhi ","outvill "] <- sum(SAMmatrix[,"aofffhmhi "]) - 1
 SAMmatrix["aofffhmmd ","outvill "] <- sum(SAMmatrix[,"aofffhmmd "])
 SAMmatrix["aofffhmlo ","outvill "] <- sum(SAMmatrix[,"aofffhmlo "]) + 1

# Note on SAM balancing: This adjustment of payments from outvill to aoffinf causes that the total returns from local informal off-farm work remain constant after changing the ag. input use. The adjustment only shifts the balance between off-farm work inside the village and those outside the village. This is acceptable, as teh cahnge are only of minor magnitude and as offinf is treated as one singly activity with the same returns to labor, anyway. 

 SAMmatrix["aoffilmhi ","outvill "] <- sum(SAMmatrix[,"aoffilmhi "]) - SAMmatrix["aoffilmhi ","clabagvil "] - 1
 SAMmatrix["aoffilmmd ","outvill "] <- sum(SAMmatrix[,"aoffilmmd "]) - SAMmatrix["aoffilmmd ","clabagvil "] - 1
 SAMmatrix["aoffilmlo ","outvill "] <- sum(SAMmatrix[,"aoffilmlo "]) - SAMmatrix["aoffilmlo ","clabagvil "] + 1
 SAMmatrix["aoffihmhi ","outvill "] <- sum(SAMmatrix[,"aoffihmhi "]) - SAMmatrix["aoffihmhi ","clabagvil "] 
 SAMmatrix["aoffihmmd ","outvill "] <- sum(SAMmatrix[,"aoffihmmd "]) - SAMmatrix["aoffihmmd ","clabagvil "] 
 SAMmatrix["aoffihmlo ","outvill "] <- sum(SAMmatrix[,"aoffihmlo "]) - SAMmatrix["aoffihmlo ","clabagvil "] 

# 30. RETURNS FROM MIGRATION (Remittances)

 SAMmatrix["amiglmhi ","outvill "] <- sum(SAMmatrix[,"amiglmhi "])
 SAMmatrix["amiglmmd ","outvill "] <- sum(SAMmatrix[,"amiglmmd "])
 SAMmatrix["amiglmlo ","outvill "] <- sum(SAMmatrix[,"amiglmlo "]) 
 SAMmatrix["amighmhi ","outvill "] <- sum(SAMmatrix[,"amighmhi "])
 SAMmatrix["amighmmd ","outvill "] <- sum(SAMmatrix[,"amighmmd "]) + 1
 SAMmatrix["amighmlo ","outvill "] <- sum(SAMmatrix[,"amighmlo "])

## 31.### SAM balancing: REWRITE CELLS WITH HOUSEHOLD SUPPLY OF CROP AND LIVESTOCK ACTIVITIES. Scale original values. 
# Agriculture
# agralagg <- aggregate((corninc+maizeinc+rapeinc+oilinc+riceinc+paddyinc+ograininc+ocropinc+
#                         veginc+fruitinc+
#                         piginc+cowinc+poultryinc+egginc+oanimalinc+
#                         forestryinc+fisheryinc+rentinc+processinc+otherinc.x
#                         ),by=list(RHG),FUN=sum)
# SAMmatrix["aagrlmhi ","cagr "] <- agralagg$x[1] 
# SAMmatrix["aagrlmmd ","cagr "] <- agralagg$x[2] 
# SAMmatrix["aagrlmlo ","cagr "] <- agralagg$x[3] 
# SAMmatrix["aagrhmhi ","cagr "] <- agralagg$x[4] 
# SAMmatrix["aagrhmmd ","cagr "] <- agralagg$x[5] 
# SAMmatrix["aagrhmlo ","cagr "] <- agralagg$x[6] 

 SAMmatrix <- round(SAMmatrix,0)
## Write SAM into file
 write.csv2(SAMmatrix,"out/SAM/SAMhhdisagg_actagg_agragg.csv")

detach(SAMdat1) 
